@@ -2,12 +2,9 @@
 
 # flake8: noqa
 
-try:
-    import importlib.metadata as importlib_metadata
-except ModuleNotFoundError:
-    import importlib_metadata
+import pkg_resources
 
-__version__ = importlib_metadata.version(__name__)
+__version__ = pkg_resources.get_distribution(__name__).version
 
 
 import sys
@@ -42,6 +39,7 @@ from .animation.indication import *
 from .animation.movement import *
 from .animation.numbers import *
 from .animation.rotation import *
+from .animation.specialized import *
 from .animation.transform import *
 from .animation.transform_matching_parts import *
 from .animation.update import *
@@ -51,7 +49,6 @@ from .camera.moving_camera import *
 from .camera.multi_camera import *
 from .camera.three_d_camera import *
 from .constants import *
-from .container import *
 from .mobject.changing import *
 from .mobject.coordinate_systems import *
 from .mobject.frame import *
@@ -74,15 +71,17 @@ from .mobject.svg.svg_mobject import *
 from .mobject.svg.svg_path import *
 from .mobject.svg.tex_mobject import *
 from .mobject.svg.text_mobject import *
+from .mobject.table import *
 from .mobject.three_d_utils import *
 from .mobject.three_dimensions import *
+from .mobject.types.dot_cloud import *
 from .mobject.types.image_mobject import *
+from .mobject.types.opengl_point_cloud_mobject import *
 from .mobject.types.point_cloud_mobject import *
 from .mobject.types.vectorized_mobject import *
 from .mobject.value_tracker import *
 from .mobject.vector_field import *
 from .renderer.cairo_renderer import *
-from .scene.graph_scene import *
 from .scene.moving_camera_scene import *
 from .scene.reconfigurable_scene import *
 from .scene.sample_space_scene import *
