@@ -59,6 +59,8 @@ class AnimationGroup(Animation):
 
     def clean_up_from_scene(self, scene: Scene) -> None:
         for anim in self.animations:
+            if self.remover:
+                anim.remover = self.remover
             anim.clean_up_from_scene(scene)
 
     def update_mobjects(self, dt: float) -> None:
