@@ -8,15 +8,14 @@ __all__ = [
     "MoveAlongPath",
 ]
 
-import typing
-from typing import Any, Callable, Dict, Optional, Tuple
+from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, Tuple
 
 import numpy as np
 
 from ..animation.animation import Animation
 from ..utils.rate_functions import linear
 
-if typing.TYPE_CHECKING:
+if TYPE_CHECKING:
     from ..mobject.mobject import Mobject
 
 
@@ -97,7 +96,9 @@ class PhaseFlow(Animation):
 
     def interpolate_mobject(self, alpha: float) -> None:
         if hasattr(self, "last_alpha"):
-            dt = self.virtual_time * (alpha - self.last_alpha)
+            dt = self.virtual_time * (
+                self.rate_func(alpha) - self.rate_func(self.last_alpha)
+            )
             self.mobject.apply_function(lambda p: p + dt * self.function(p))
         self.last_alpha = alpha
 
@@ -131,5 +132,5 @@ class MoveAlongPath(Animation):
         )
 
     def interpolate_mobject(self, alpha: float) -> None:
-        point = self.path.point_from_proportion(alpha)
+        point = self.path.point_from_proportion(self.rate_func(alpha))
         self.mobject.move_to(point)
