@@ -26,7 +26,7 @@ __all__ = [
 
 import inspect
 import types
-from typing import TYPE_CHECKING, Any, Callable, Iterable, List, Optional, Sequence
+from typing import TYPE_CHECKING, Any, Callable, Iterable, Optional, Sequence
 
 import numpy as np
 
@@ -50,10 +50,12 @@ class Transform(Animation):
         path_func: Optional[Callable] = None,
         path_arc: float = 0,
         path_arc_axis: np.ndarray = OUT,
+        path_arc_centers: np.ndarray = None,
         replace_mobject_with_target_in_scene: bool = False,
         **kwargs,
     ) -> None:
         self.path_arc_axis: np.ndarray = path_arc_axis
+        self.path_arc_centers: np.ndarray = path_arc_centers
         self.path_arc: float = path_arc
         self.path_func: Optional[Callable] = path_func
         self.replace_mobject_with_target_in_scene: bool = (
@@ -71,7 +73,11 @@ class Transform(Animation):
     @path_arc.setter
     def path_arc(self, path_arc: float) -> None:
         self._path_arc = path_arc
-        self._path_func = path_along_arc(self._path_arc, self.path_arc_axis)
+        self._path_func = path_along_arc(
+            arc_angle=self._path_arc,
+            axis=self.path_arc_axis,
+            arc_centers=self.path_arc_centers,
+        )
 
     @property
     def path_func(
@@ -130,7 +136,7 @@ class Transform(Animation):
             self.starting_mobject,
             self.target_copy,
         ]
-        return zip(*[mob.family_members_with_points() for mob in mobs])
+        return zip(*(mob.family_members_with_points() for mob in mobs))
 
     def interpolate_submobject(
         self,
@@ -144,6 +150,53 @@ class Transform(Animation):
 
 
 class ReplacementTransform(Transform):
+    """Replaces and morphs a mobject into a target mobject.
+
+    Parameters
+    ----------
+    mobject
+        The starting :class:`~.Mobject`.
+    target_mobject
+        The target :class:`~.Mobject`.
+    kwargs
+        Further keyword arguments that are passed to :class:`Transform`.
+
+    Examples
+    --------
+
+    .. manim:: ReplacementTransformOrTransform
+        :quality: low
+
+        class ReplacementTransformOrTransform(Scene):
+            def construct(self):
+                # set up the numbers
+                r_transform = VGroup(*[Integer(i) for i in range(1,4)])
+                text_1 = Text("ReplacementTransform", color=RED)
+                r_transform.add(text_1)
+
+                transform = VGroup(*[Integer(i) for i in range(4,7)])
+                text_2 = Text("Transform", color=BLUE)
+                transform.add(text_2)
+
+                ints = VGroup(r_transform, transform)
+                texts = VGroup(text_1, text_2).scale(0.75)
+                r_transform.arrange(direction=UP, buff=1)
+                transform.arrange(direction=UP, buff=1)
+
+                ints.arrange(buff=2)
+                self.add(ints, texts)
+
+                # The mobs replace each other and none are left behind
+                self.play(ReplacementTransform(r_transform[0], r_transform[1]))
+                self.play(ReplacementTransform(r_transform[1], r_transform[2]))
+
+                # The mobs linger after the Transform()
+                self.play(Transform(transform[0], transform[1]))
+                self.play(Transform(transform[1], transform[2]))
+                self.wait()
+
+    """
+
     def __init__(self, mobject: Mobject, target_mobject: Mobject, **kwargs) -> None:
         super().__init__(
             mobject, target_mobject, replace_mobject_with_target_in_scene=True, **kwargs
