@@ -16,13 +16,14 @@ from ...utils.file_ops import copy_template_files
 @click.command(
     context_settings=CONTEXT_SETTINGS,
     epilog=EPILOG,
+    short_help="""Sets up a new project in current working directory with default settings.\n
+It copies files from templates directory and pastes them in the current working dir.
+""",
 )
 def init():
-    """Sets up a project in current working directory with default settings.
+    """Sets up a new project in current working directory with default settings.
 
     It copies files from templates directory and pastes them in the current working dir.
-
-    The new project is set up with default settings.
     """
     cfg = Path("manim.cfg")
     if cfg.exists():
