@@ -8,14 +8,13 @@ can specify options, and arguments for the render command.
 import json
 import sys
 from pathlib import Path
-from textwrap import dedent
 
 import click
 import cloup
 import requests
 
 from ... import __version__, config, console, error_console, logger
-from ...constants import CONTEXT_SETTINGS, EPILOG
+from ...constants import EPILOG
 from ...utils.module_ops import scene_classes_from_file
 from .ease_of_access_options import ease_of_access_options
 from .global_options import global_options
@@ -42,27 +41,6 @@ def render(
 
     SCENES is an optional list of scenes in the file.
     """
-    for scene in args["scene_names"]:
-        if str(scene).startswith("-"):
-            logger.warning(
-                dedent(
-                    """\
-                Manim Community has moved to Click for the CLI.
-
-                This means that options in the CLI are provided BEFORE the positional
-                arguments for your FILE and SCENE(s):
-                `manim render [OPTIONS] [FILE] [SCENES]...`
-
-                For example:
-                New way - `manim -p -ql file.py SceneName1 SceneName2 ...`
-                Old way - `manim file.py SceneName1 SceneName2 ... -p -ql`
-
-                To see the help page for the new available options, run:
-                `manim render -h`
-                """
-                )
-            )
-            sys.exit()
 
     if args["use_opengl_renderer"]:
         logger.warning(
@@ -121,21 +99,21 @@ def render(
     if config.renderer == "opengl":
         from manim.renderer.opengl_renderer import OpenGLRenderer
 
-        for SceneClass in scene_classes_from_file(file):
-            try:
-                renderer = OpenGLRenderer()
-                while True:
-                    scene_classes = scene_classes_from_file(file)
-                    SceneClass = scene_classes[0]
+        try:
+            renderer = OpenGLRenderer()
+            keep_running = True
+            while keep_running:
+                for SceneClass in scene_classes_from_file(file):
                     scene = SceneClass(renderer)
                     status = scene.render()
                     if status:
                         continue
                     else:
+                        keep_running = False
                         break
-            except Exception:
-                error_console.print_exception()
-                sys.exit(1)
+        except Exception:
+            error_console.print_exception()
+            sys.exit(1)
     elif config.renderer == "webgl":
         try:
             from manim.grpc.impl import frame_server_impl
