@@ -3,14 +3,18 @@ import itertools as it
 import random
 import sys
 from functools import wraps
+from math import ceil
+from typing import Iterable, Optional, Tuple, Union
 
 import moderngl
 import numpy as np
+from colour import Color
 
 from .. import config
 from ..constants import *
-from ..utils.bezier import interpolate
+from ..utils.bezier import integer_interpolate, interpolate
 from ..utils.color import *
+from ..utils.config_ops import _Data, _Uniforms
 
 # from ..utils.iterables import batch_by_property
 from ..utils.iterables import (
@@ -24,7 +28,11 @@ from ..utils.iterables import (
 )
 from ..utils.paths import straight_path
 from ..utils.simple_functions import get_parameters
-from ..utils.space_ops import angle_of_vector, rotation_matrix_transpose
+from ..utils.space_ops import (
+    angle_between_vectors,
+    normalize,
+    rotation_matrix_transpose,
+)
 
 
 class OpenGLMobject:
@@ -37,6 +45,15 @@ class OpenGLMobject:
     ]
     shader_folder = ""
 
+    # _Data and _Uniforms are set as class variables to tell manim how to handle setting/getting these attributes later.
+    points = _Data()
+    bounding_box = _Data()
+    rgbas = _Data()
+
+    is_fixed_in_frame = _Uniforms()
+    gloss = _Uniforms()
+    shadow = _Uniforms()
+
     def __init__(
         self,
         color=WHITE,
@@ -48,7 +65,7 @@ class OpenGLMobject:
         # Positive shadow up to 1 makes a side opposite the light darker
         shadow=0.0,
         # For shaders
-        render_primitive=moderngl.TRIANGLE_STRIP,
+        render_primitive=moderngl.TRIANGLES,
         texture_paths=None,
         depth_test=False,
         # If true, the mobject will not get rotated according to camera position
@@ -56,10 +73,14 @@ class OpenGLMobject:
         # Must match in attributes of vert shader
         # Event listener
         listen_to_events=False,
+        model_matrix=None,
         **kwargs,
     ):
+        # getattr in case data/uniforms are already defined in parent classes.
+        self.data = getattr(self, "data", {})
+        self.uniforms = getattr(self, "uniforms", {})
 
-        self.color = color
+        self.color = Color(color)
         self.opacity = opacity
         self.dim = dim  # TODO, get rid of this
         # Lighting parameters
@@ -72,19 +93,23 @@ class OpenGLMobject:
         self.texture_paths = texture_paths
         self.depth_test = depth_test
         # If true, the mobject will not get rotated according to camera position
-        self.is_fixed_in_frame = is_fixed_in_frame
+        self.is_fixed_in_frame = float(is_fixed_in_frame)
         # Must match in attributes of vert shader
         # Event listener
         self.listen_to_events = listen_to_events
 
         self.submobjects = []
         self.parents = []
+        self.parent = None
         self.family = [self]
         self.locked_data_keys = set()
         self.needs_new_bounding_box = True
+        if model_matrix is None:
+            self.model_matrix = np.eye(4)
+        else:
+            self.model_matrix = model_matrix
 
         self.init_data()
-        self.init_uniforms()
         self.init_updaters()
         # self.init_event_listners()
         self.init_points()
@@ -99,24 +124,17 @@ class OpenGLMobject:
         return self.__class__.__name__
 
     def init_data(self):
-        self.data = {
-            "points": np.zeros((0, 3)),
-            "bounding_box": np.zeros((3, 3)),
-            "rgbas": np.zeros((1, 4)),
-        }
-
-    def init_uniforms(self):
-        self.uniforms = {
-            "is_fixed_in_frame": float(self.is_fixed_in_frame),
-            "gloss": self.gloss,
-            "shadow": self.shadow,
-        }
+        """Initializes the ``points``, ``bounding_box`` and ``rgbas`` attributes and groups them into self.data.
+        Subclasses can inherit and overwrite this method to extend `self.data`."""
+        self.points = np.zeros((0, 3))
+        self.bounding_box = np.zeros((3, 3))
+        self.rgbas = np.zeros((1, 4))
 
     def init_colors(self):
         self.set_color(self.color, self.opacity)
 
     def init_points(self):
-        # Typically implemented in subclass, unlpess purposefully left blank
+        # Typically implemented in subclass, unless purposefully left blank
         pass
 
     def set_data(self, data):
@@ -231,23 +249,28 @@ class OpenGLMobject:
         self.rescale_to_fit(value, 2, stretch=False)
 
     def resize_points(self, new_length, resize_func=resize_array):
-        if new_length != len(self.data["points"]):
-            self.data["points"] = resize_func(self.data["points"], new_length)
+        if new_length != len(self.points):
+            self.points = resize_func(self.points, new_length)
         self.refresh_bounding_box()
         return self
 
     def set_points(self, points):
-        if len(points) == len(self.data["points"]):
-            self.data["points"][:] = points
+        if len(points) == len(self.points):
+            self.points[:] = points
         elif isinstance(points, np.ndarray):
-            self.data["points"] = points.copy()
+            self.points = points.copy()
         else:
-            self.data["points"] = np.array(points)
+            self.points = np.array(points)
         self.refresh_bounding_box()
         return self
 
+    def apply_over_attr_arrays(self, func):
+        for attr in self.get_array_attrs():
+            setattr(self, attr, func(getattr(self, attr)))
+        return self
+
     def append_points(self, new_points):
-        self.data["points"] = np.vstack([self.data["points"], new_points])
+        self.points = np.vstack([self.points, new_points])
         self.refresh_bounding_box()
         return self
 
@@ -257,6 +280,9 @@ class OpenGLMobject:
                 mob.data[key] = mob.data[key][::-1]
         return self
 
+    def get_midpoint(self):
+        return self.point_from_proportion(0.5)
+
     def apply_points_function(
         self, func, about_point=None, about_edge=ORIGIN, works_on_bounding_box=False
     ):
@@ -289,33 +315,33 @@ class OpenGLMobject:
         self.set_points(mobject.get_points())
 
     def get_points(self):
-        return self.data["points"]
+        return self.points
 
     def clear_points(self):
         self.resize_points(0)
 
     def get_num_points(self):
-        return len(self.data["points"])
+        return len(self.points)
 
     def get_all_points(self):
         if self.submobjects:
             return np.vstack([sm.get_points() for sm in self.get_family()])
         else:
-            return self.get_points()
+            return self.points
 
     def has_points(self):
         return self.get_num_points() > 0
 
     def get_bounding_box(self):
         if self.needs_new_bounding_box:
-            self.data["bounding_box"] = self.compute_bounding_box()
+            self.bounding_box = self.compute_bounding_box()
             self.needs_new_bounding_box = False
-        return self.data["bounding_box"]
+        return self.bounding_box
 
     def compute_bounding_box(self):
         all_points = np.vstack(
             [
-                self.get_points(),
+                self.points,
                 *(
                     mob.get_bounding_box()
                     for mob in self.get_family()[1:]
@@ -381,7 +407,11 @@ class OpenGLMobject:
     def family_members_with_points(self):
         return [m for m in self.get_family() if m.has_points()]
 
-    def add(self, *mobjects):
+    def add(self, *mobjects, update_parent=False):
+        if update_parent:
+            assert len(mobjects) == 1, "Can't set multiple parents."
+            mobjects[0].parent = self
+
         if self in mobjects:
             raise Exception("Mobject cannot contain self")
         for mobject in mobjects:
@@ -392,7 +422,11 @@ class OpenGLMobject:
         self.assemble_family()
         return self
 
-    def remove(self, *mobjects):
+    def remove(self, *mobjects, update_parent=False):
+        if update_parent:
+            assert len(mobjects) == 1, "Can't remove multiple parents."
+            mobjects[0].parent = None
+
         for mobject in mobjects:
             if mobject in self.submobjects:
                 self.submobjects.remove(mobject)
@@ -418,6 +452,33 @@ class OpenGLMobject:
         self.add(*submobject_list)
         return self
 
+    def invert(self, recursive=False):
+        """Inverts the list of :attr:`submobjects`.
+
+        Parameters
+        ----------
+        recursive
+            If ``True``, all submobject lists of this mobject's family are inverted.
+
+        Examples
+        --------
+
+        .. manim:: InvertSumobjectsExample
+
+            class InvertSumobjectsExample(Scene):
+                def construct(self):
+                    s = VGroup(*[Dot().shift(i*0.1*RIGHT) for i in range(-20,20)])
+                    s2 = s.copy()
+                    s2.invert()
+                    s2.shift(DOWN)
+                    self.play(Write(s), Write(s2))
+        """
+        if recursive:
+            for submob in self.submobjects:
+                submob.invert(recursive=True)
+        list.reverse(self.submobjects)
+        self.assemble_family()
+
     def digest_mobject_attrs(self):
         """
         Ensures all attributes which are mobjects are included
@@ -440,48 +501,238 @@ class OpenGLMobject:
 
     def arrange_in_grid(
         self,
-        n_rows=None,
-        n_cols=None,
-        buff=None,
-        h_buff=None,
-        v_buff=None,
-        buff_ratio=None,
-        h_buff_ratio=0.5,
-        v_buff_ratio=0.5,
-        aligned_edge=ORIGIN,
-        fill_rows_first=True,
-    ):
-        submobs = self.submobjects
-        if n_rows is None and n_cols is None:
-            n_rows = int(np.sqrt(len(submobs)))
-        if n_rows is None:
-            n_rows = len(submobs) // n_cols
-        if n_cols is None:
-            n_cols = len(submobs) // n_rows
+        rows: Optional[int] = None,
+        cols: Optional[int] = None,
+        buff: Union[float, Tuple[float, float]] = MED_SMALL_BUFF,
+        cell_alignment: np.ndarray = ORIGIN,
+        row_alignments: Optional[str] = None,  # "ucd"
+        col_alignments: Optional[str] = None,  # "lcr"
+        row_heights: Optional[Iterable[Optional[float]]] = None,
+        col_widths: Optional[Iterable[Optional[float]]] = None,
+        flow_order: str = "rd",
+        **kwargs,
+    ) -> "OpenGLMobject":
+        """Arrange submobjects in a grid.
 
-        if buff is not None:
-            h_buff = buff
-            v_buff = buff
+        Parameters
+        ----------
+        rows
+            The number of rows in the grid.
+        cols
+            The number of columns in the grid.
+        buff
+            The gap between grid cells. To specify a different buffer in the horizontal and
+            vertical directions, a tuple of two values can be given - ``(row, col)``.
+        cell_alignment
+            The way each submobject is aligned in its grid cell.
+        row_alignments
+            The vertical alignment for each row (top to bottom). Accepts the following characters: ``"u"`` -
+            up, ``"c"`` - center, ``"d"`` - down.
+        col_alignments
+            The horizontal alignment for each column (left to right). Accepts the following characters ``"l"`` - left,
+            ``"c"`` - center, ``"r"`` - right.
+        row_heights
+            Defines a list of heights for certain rows (top to bottom). If the list contains
+            ``None``, the corresponding row will fit its height automatically based
+            on the highest element in that row.
+        col_widths
+            Defines a list of widths for certain columns (left to right). If the list contains ``None``, the
+            corresponding column will fit its width automatically based on the widest element in that column.
+        flow_order
+            The order in which submobjects fill the grid. Can be one of the following values:
+            "rd", "dr", "ld", "dl", "ru", "ur", "lu", "ul". ("rd" -> fill rightwards then downwards)
+
+        Returns
+        -------
+        Mobject
+            The mobject.
+
+        NOTES
+        -----
+
+        If only one of ``cols`` and ``rows`` is set implicitly, the other one will be chosen big
+        enough to fit all submobjects. If neither is set, they will be chosen to be about the same,
+        tending towards ``cols`` > ``rows`` (simply because videos are wider than they are high).
+
+        If both ``cell_alignment`` and ``row_alignments`` / ``col_alignments`` are
+        defined, the latter has higher priority.
+
+
+        Raises
+        ------
+        ValueError
+            If ``rows`` and ``cols`` are too small to fit all submobjects.
+        ValueError
+            If :code:`cols`, :code:`col_alignments` and :code:`col_widths` or :code:`rows`,
+            :code:`row_alignments` and :code:`row_heights` have mismatching sizes.
+
+        Examples
+        --------
+        .. manim:: ExampleBoxes
+            :save_last_frame:
+
+            class ExampleBoxes(Scene):
+                def construct(self):
+                    boxes=VGroup(*[Square() for s in range(0,6)])
+                    boxes.arrange_in_grid(rows=2, buff=0.1)
+                    self.add(boxes)
+
+
+        .. manim:: ArrangeInGrid
+            :save_last_frame:
+
+            class ArrangeInGrid(Scene):
+                def construct(self):
+                    #Add some numbered boxes:
+                    np.random.seed(3)
+                    boxes = VGroup(*[
+                        Rectangle(WHITE, np.random.random()+.5, np.random.random()+.5).add(Text(str(i+1)).scale(0.5))
+                        for i in range(22)
+                    ])
+                    self.add(boxes)
+
+                    boxes.arrange_in_grid(
+                        buff=(0.25,0.5),
+                        col_alignments="lccccr",
+                        row_alignments="uccd",
+                        col_widths=[2, *[None]*4, 2],
+                        flow_order="dr"
+                    )
+
+
+        """
+        from .geometry import Line
+
+        mobs = self.submobjects.copy()
+        start_pos = self.get_center()
+
+        # get cols / rows values if given (implicitly)
+        def init_size(num, alignments, sizes):
+            if num is not None:
+                return num
+            if alignments is not None:
+                return len(alignments)
+            if sizes is not None:
+                return len(sizes)
+
+        cols = init_size(cols, col_alignments, col_widths)
+        rows = init_size(rows, row_alignments, row_heights)
+
+        # calculate rows cols
+        if rows is None and cols is None:
+            cols = ceil(np.sqrt(len(mobs)))
+            # make the grid as close to quadratic as possible.
+            # choosing cols first can results in cols>rows.
+            # This is favored over rows>cols since in general
+            # the sceene is wider than high.
+        if rows is None:
+            rows = ceil(len(mobs) / cols)
+        if cols is None:
+            cols = ceil(len(mobs) / rows)
+        if rows * cols < len(mobs):
+            raise ValueError("Too few rows and columns to fit all submobjetcs.")
+        # rows and cols are now finally valid.
+
+        if isinstance(buff, tuple):
+            buff_x = buff[0]
+            buff_y = buff[1]
         else:
-            if buff_ratio is not None:
-                v_buff_ratio = buff_ratio
-                h_buff_ratio = buff_ratio
-            if h_buff is None:
-                h_buff = h_buff_ratio * self[0].get_width()
-            if v_buff is None:
-                v_buff = v_buff_ratio * self[0].get_height()
+            buff_x = buff_y = buff
 
-        x_unit = h_buff + max([sm.get_width() for sm in submobs])
-        y_unit = v_buff + max([sm.get_height() for sm in submobs])
+        # Initialize alignments correctly
+        def init_alignments(alignments, num, mapping, name, dir):
+            if alignments is None:
+                # Use cell_alignment as fallback
+                return [cell_alignment * dir] * num
+            if len(alignments) != num:
+                raise ValueError(f"{name}_alignments has a mismatching size.")
+            alignments = list(alignments)
+            for i in range(num):
+                alignments[i] = mapping[alignments[i]]
+            return alignments
 
-        for index, sm in enumerate(submobs):
-            if fill_rows_first:
-                x, y = index % n_cols, index // n_cols
-            else:
-                x, y = index // n_rows, index % n_rows
-            sm.move_to(ORIGIN, aligned_edge)
-            sm.shift(x * x_unit * RIGHT + y * y_unit * DOWN)
-        self.center()
+        row_alignments = init_alignments(
+            row_alignments, rows, {"u": UP, "c": ORIGIN, "d": DOWN}, "row", RIGHT
+        )
+        col_alignments = init_alignments(
+            col_alignments, cols, {"l": LEFT, "c": ORIGIN, "r": RIGHT}, "col", UP
+        )
+        # Now row_alignment[r] + col_alignment[c] is the alignment in cell [r][c]
+
+        mapper = {
+            "dr": lambda r, c: (rows - r - 1) + c * rows,
+            "dl": lambda r, c: (rows - r - 1) + (cols - c - 1) * rows,
+            "ur": lambda r, c: r + c * rows,
+            "ul": lambda r, c: r + (cols - c - 1) * rows,
+            "rd": lambda r, c: (rows - r - 1) * cols + c,
+            "ld": lambda r, c: (rows - r - 1) * cols + (cols - c - 1),
+            "ru": lambda r, c: r * cols + c,
+            "lu": lambda r, c: r * cols + (cols - c - 1),
+        }
+        if flow_order not in mapper:
+            raise ValueError(
+                'flow_order must be one of the following values: "dr", "rd", "ld" "dl", "ru", "ur", "lu", "ul".'
+            )
+        flow_order = mapper[flow_order]
+
+        # Reverse row_alignments and row_heights. Necessary since the
+        # grid filling is handled bottom up for simplicity reasons.
+        def reverse(maybe_list):
+            if maybe_list is not None:
+                maybe_list = list(maybe_list)
+                maybe_list.reverse()
+                return maybe_list
+
+        row_alignments = reverse(row_alignments)
+        row_heights = reverse(row_heights)
+
+        placeholder = OpenGLMobject()
+        # Used to fill up the grid temporarily, doesn't get added to the scene.
+        # In this case a Mobject is better than None since it has width and height
+        # properties of 0.
+
+        mobs.extend([placeholder] * (rows * cols - len(mobs)))
+        grid = [[mobs[flow_order(r, c)] for c in range(cols)] for r in range(rows)]
+
+        measured_heigths = [
+            max(grid[r][c].height for c in range(cols)) for r in range(rows)
+        ]
+        measured_widths = [
+            max(grid[r][c].width for r in range(rows)) for c in range(cols)
+        ]
+
+        # Initialize row_heights / col_widths correctly using measurements as fallback
+        def init_sizes(sizes, num, measures, name):
+            if sizes is None:
+                sizes = [None] * num
+            if len(sizes) != num:
+                raise ValueError(f"{name} has a mismatching size.")
+            return [
+                sizes[i] if sizes[i] is not None else measures[i] for i in range(num)
+            ]
+
+        heights = init_sizes(row_heights, rows, measured_heigths, "row_heights")
+        widths = init_sizes(col_widths, cols, measured_widths, "col_widths")
+
+        x, y = 0, 0
+        for r in range(rows):
+            x = 0
+            for c in range(cols):
+                if grid[r][c] is not placeholder:
+                    alignment = row_alignments[r] + col_alignments[c]
+                    line = Line(
+                        x * RIGHT + y * UP,
+                        (x + widths[c]) * RIGHT + (y + heights[r]) * UP,
+                    )
+                    # Use a mobject to avoid rewriting align inside
+                    # box code that Mobject.move_to(Mobject) already
+                    # includes.
+
+                    grid[r][c].move_to(line, alignment)
+                x += widths[c] + buff_x
+            y += heights[r] + buff_y
+
+        self.move_to(start_pos)
         return self
 
     def get_grid(self, n_rows, n_cols, height=None, **kwargs):
@@ -507,11 +758,22 @@ class OpenGLMobject:
             for submob in self.submobjects:
                 submob.shuffle(recurse=True)
         random.shuffle(self.submobjects)
+        self.assemble_family()
         return self
 
     # Copying
 
-    def copy(self):
+    def copy(self, shallow: bool = False):
+        """Copies the mobject.
+
+        Parameters
+        ----------
+        shallow
+            Controls whether a shallow copy is returned.
+        """
+        if not shallow:
+            return self.deepcopy()
+
         # TODO, either justify reason for shallow copy, or
         # remove this redundancy everywhere
         # return self.deepcopy()
@@ -529,7 +791,7 @@ class OpenGLMobject:
         copy_mobject.uniforms = dict(self.uniforms)
 
         copy_mobject.submobjects = []
-        copy_mobject.add(*[sm.copy() for sm in self.submobjects])
+        copy_mobject.add(*(sm.copy() for sm in self.submobjects))
         copy_mobject.match_updaters(self)
 
         copy_mobject.needs_new_bounding_box = self.needs_new_bounding_box
@@ -610,7 +872,7 @@ class OpenGLMobject:
         return self.time_based_updaters + self.non_time_updaters
 
     def get_family_updaters(self):
-        return list(it.chain(*[sm.get_updaters() for sm in self.get_family()]))
+        return list(it.chain(*(sm.get_updaters() for sm in self.get_family())))
 
     def add_updater(self, update_function, index=None, call_updater=True):
         if "dt" in get_parameters(update_function):
@@ -761,6 +1023,17 @@ class OpenGLMobject:
 
         return self.apply_function(R3_func)
 
+    def hierarchical_model_matrix(self):
+        if self.parent is None:
+            return self.model_matrix
+
+        model_matrices = [self.model_matrix]
+        current_object = self
+        while current_object.parent is not None:
+            model_matrices.append(current_object.parent.model_matrix)
+            current_object = current_object.parent
+        return np.linalg.multi_dot(list(reversed(model_matrices)))
+
     def wag(self, direction=RIGHT, axis=DOWN, wag_factor=1.0):
         for mob in self.family_members_with_points():
             alphas = np.dot(mob.get_points(), np.transpose(axis))
@@ -950,19 +1223,24 @@ class OpenGLMobject:
         return self
 
     def put_start_and_end_on(self, start, end):
-        # TODO, this doesn't currently work in 3d
         curr_start, curr_end = self.get_start_and_end()
         curr_vect = curr_end - curr_start
         if np.all(curr_vect == 0):
             raise Exception("Cannot position endpoints of closed loop")
-        target_vect = end - start
+        target_vect = np.array(end) - np.array(start)
+        axis = (
+            normalize(np.cross(curr_vect, target_vect))
+            if np.linalg.norm(np.cross(curr_vect, target_vect)) != 0
+            else OUT
+        )
         self.scale(
             np.linalg.norm(target_vect) / np.linalg.norm(curr_vect),
             about_point=curr_start,
         )
         self.rotate(
-            angle_of_vector(target_vect) - angle_of_vector(curr_vect),
+            angle_between_vectors(curr_vect, target_vect),
             about_point=curr_start,
+            axis=axis,
         )
         self.shift(start - curr_start)
         return self
@@ -994,6 +1272,23 @@ class OpenGLMobject:
                 mob.data[name] = rgbas.copy()
         return self
 
+    def set_rgba_array_direct(self, rgbas: np.ndarray, name="rgbas", recurse=True):
+        """Directly set rgba data from `rgbas` and optionally do the same recursively
+        with submobjects. This can be used if the `rgbas` have already been generated
+        with the correct shape and simply need to be set.
+
+        Parameters
+        ----------
+        rgbas
+            the rgba to be set as data
+        name
+            the name of the data attribute to be set
+        recurse
+            set to true to recursively apply this method to submobjects
+        """
+        for mob in self.get_family(recurse):
+            mob.data[name] = rgbas.copy()
+
     def set_color(self, color, opacity=None, recurse=True):
         self.set_rgba_array(color, opacity, recurse=False)
         # Recurse to submobjects differently from how set_rgba_array
@@ -1011,10 +1306,10 @@ class OpenGLMobject:
         return self
 
     def get_color(self):
-        return rgb_to_hex(self.data["rgbas"][0, :3])
+        return rgb_to_hex(self.rgbas[0, :3])
 
     def get_opacity(self):
-        return self.data["rgbas"][0, 3]
+        return self.rgbas[0, 3]
 
     def set_color_by_gradient(self, *colors):
         self.set_submobject_colors_by_gradient(*colors)
@@ -1038,19 +1333,19 @@ class OpenGLMobject:
         self.set_opacity(1.0 - darkness, recurse=recurse)
 
     def get_gloss(self):
-        return self.uniforms["gloss"]
+        return self.gloss
 
     def set_gloss(self, gloss, recurse=True):
         for mob in self.get_family(recurse):
-            mob.uniforms["gloss"] = gloss
+            mob.gloss = gloss
         return self
 
     def get_shadow(self):
-        return self.uniforms["shadow"]
+        return self.shadow
 
     def set_shadow(self, shadow, recurse=True):
         for mob in self.get_family(recurse):
-            mob.uniforms["shadow"] = shadow
+            mob.shadow = shadow
         return self
 
     # Background rectangle
@@ -1058,7 +1353,7 @@ class OpenGLMobject:
     def add_background_rectangle(self, color=None, opacity=0.75, **kwargs):
         # TODO, this does not behave well when the mobject has points,
         # since it gets displayed on top
-        from manimlib.mobject.shape_matchers import BackgroundRectangle
+        from ..mobject.shape_matchers import BackgroundRectangle
 
         self.background_rectangle = BackgroundRectangle(
             self, color=color, fill_opacity=opacity, **kwargs
@@ -1165,17 +1460,17 @@ class OpenGLMobject:
 
     def get_start(self):
         self.throw_error_if_no_points()
-        return np.array(self.get_points()[0])
+        return np.array(self.points[0])
 
     def get_end(self):
         self.throw_error_if_no_points()
-        return np.array(self.get_points()[-1])
+        return np.array(self.points[-1])
 
     def get_start_and_end(self):
         return self.get_start(), self.get_end()
 
     def point_from_proportion(self, alpha):
-        points = self.get_points()
+        points = self.points
         i, subalpha = integer_interpolate(0, len(points) - 1, alpha)
         return interpolate(points[i], points[i + 1], subalpha)
 
@@ -1188,10 +1483,10 @@ class OpenGLMobject:
         template.set_submobjects([])
         alphas = np.linspace(0, 1, n_pieces + 1)
         return OpenGLGroup(
-            *[
+            *(
                 template.copy().pointwise_become_partial(self, a1, a2)
                 for a1, a2 in zip(alphas[:-1], alphas[1:])
-            ]
+            )
         )
 
     def get_z_index_reference_point(self):
@@ -1424,12 +1719,12 @@ class OpenGLMobject:
 
     @affects_shader_info_id
     def fix_in_frame(self):
-        self.uniforms["is_fixed_in_frame"] = 1.0
+        self.is_fixed_in_frame = 1.0
         return self
 
     @affects_shader_info_id
     def unfix_from_frame(self):
-        self.uniforms["is_fixed_in_frame"] = 0.0
+        self.is_fixed_in_frame = 0.0
         return self
 
     @affects_shader_info_id
@@ -1507,7 +1802,7 @@ class OpenGLMobject:
     def get_shader_wrapper_list(self):
         shader_wrappers = it.chain(
             [self.get_shader_wrapper()],
-            *[sm.get_shader_wrapper_list() for sm in self.submobjects],
+            *(sm.get_shader_wrapper_list() for sm in self.submobjects),
         )
         batches = batch_by_property(shader_wrappers, lambda sw: sw.get_id())
 
@@ -1535,7 +1830,7 @@ class OpenGLMobject:
     def get_resized_shader_data_array(self, length):
         # If possible, try to populate an existing array, rather
         # than recreating it each frame
-        points = self.data["points"]
+        points = self.points
         shader_data = np.zeros(len(points), dtype=self.shader_dtype)
         return shader_data
 
@@ -1597,7 +1892,7 @@ class OpenGLMobject:
         return self.event_listners
 
     def get_family_event_listners(self):
-        return list(it.chain(*[sm.get_event_listners() for sm in self.get_family()]))
+        return list(it.chain(*(sm.get_event_listners() for sm in self.get_family())))
 
     def get_has_event_listner(self):
         return any(mob.get_event_listners() for mob in self.get_family())
@@ -1677,7 +1972,7 @@ class OpenGLPoint(OpenGLMobject):
         return self.artificial_height
 
     def get_location(self):
-        return self.get_points()[0].copy()
+        return self.points[0].copy()
 
     def get_bounding_box_point(self, *args, **kwargs):
         return self.get_location()
@@ -1689,11 +1984,27 @@ class OpenGLPoint(OpenGLMobject):
 class _AnimationBuilder:
     def __init__(self, mobject):
         self.mobject = mobject
-        self.overridden_animation = None
         self.mobject.generate_target()
+
+        self.overridden_animation = None
         self.is_chaining = False
         self.methods = []
 
+        # Whether animation args can be passed
+        self.cannot_pass_args = False
+        self.anim_args = {}
+
+    def __call__(self, **kwargs):
+        if self.cannot_pass_args:
+            raise ValueError(
+                "Animation arguments must be passed before accessing methods and can only be passed once"
+            )
+
+        self.anim_args = kwargs
+        self.cannot_pass_args = True
+
+        return self
+
     def __getattr__(self, method_name):
         method = getattr(self.mobject.target, method_name)
         self.methods.append(method)
@@ -1708,22 +2019,32 @@ class _AnimationBuilder:
         def update_target(*method_args, **method_kwargs):
             if has_overridden_animation:
                 self.overridden_animation = method._override_animate(
-                    self.mobject, *method_args, **method_kwargs
+                    self.mobject,
+                    *method_args,
+                    anim_args=self.anim_args,
+                    **method_kwargs,
                 )
             else:
                 method(*method_args, **method_kwargs)
             return self
 
         self.is_chaining = True
+        self.cannot_pass_args = True
+
         return update_target
 
     def build(self):
         from ..animation.transform import _MethodAnimation
 
         if self.overridden_animation:
-            return self.overridden_animation
+            anim = self.overridden_animation
+        else:
+            anim = _MethodAnimation(self.mobject, self.methods)
 
-        return _MethodAnimation(self.mobject, self.methods)
+        for attr, value in self.anim_args.items():
+            setattr(anim, attr, value)
+
+        return anim
 
 
 def override_animate(method):
