@@ -3,6 +3,10 @@
 __all__ = ["SampleSpace", "BarChart"]
 
 
+from typing import Iterable, List
+
+import numpy as np
+
 from ..constants import *
 from ..mobject.geometry import Line, Rectangle
 from ..mobject.mobject import Mobject
@@ -26,6 +30,24 @@ EPSILON = 0.0001
 
 
 class SampleSpace(Rectangle):
+    """
+
+    Examples
+    --------
+
+    .. manim:: ExampleSampleSpace
+        :save_last_frame:
+
+        class ExampleSampleSpace(Scene):
+            def construct(self):
+                poly1 = SampleSpace(stroke_width=15, fill_opacity=1)
+                poly2 = SampleSpace(width=5, height=3, stroke_width=5, fill_opacity=0.5)
+                poly3 = SampleSpace(width=2, height=2, stroke_width=5, fill_opacity=0.1)
+                poly3.divide_vertically(p_list=np.array([0.37, 0.13, 0.5]), colors=[BLACK, WHITE, GRAY], vect=RIGHT)
+                poly_group = VGroup(poly1, poly2, poly3).arrange()
+                self.add(poly_group)
+    """
+
     def __init__(
         self,
         height=3,
@@ -156,23 +178,83 @@ class SampleSpace(Rectangle):
 
 
 class BarChart(VGroup):
+    """This is a class for Bar Charts.
+
+    Parameters
+    ----------
+    values
+        The values for the bar chart.
+    height
+        The height of the axes.
+    width
+        The width of the axes.
+    n_ticks
+        Number of ticks.
+    tick_width
+        Width of the ticks.
+    label_y_axis
+        Y axis label
+    y_axis_label_height
+        Height of the label.
+    max_value
+        Maximum value of the data.
+    bar_colors
+        The colors of the bars.
+    bar_fill_opacity
+        The opacity of the bars.
+    bar_stroke_width
+        The stroke width of the bars.
+    bar_names
+        The names of each bar.
+    bar_label_scale_val
+        The label size.
+
+    Examples
+    --------
+    .. manim:: BarChartExample
+        :save_last_frame:
+
+        class BarChartExample(Scene):
+            def construct(self):
+                pull_req = [54, 23, 47, 48, 40, 64, 112, 87]
+                versions = [
+                    "v0.1.0",
+                    "v0.1.1",
+                    "v0.2.0",
+                    "v0.3.0",
+                    "v0.4.0",
+                    "v0.5.0",
+                    "v0.6.0",
+                    "v0.7.0",
+                ]
+                colors = ["#003f5c", "#58508d", "#bc5090", "#ff6361", "#ffa600"]
+                bar = BarChart(
+                    pull_req,
+                    max_value=max(pull_req),
+                    bar_colors=colors,
+                    bar_names=versions,
+                    bar_label_scale_val=0.3,
+                )
+                self.add(bar)
+    """
+
     def __init__(
         self,
-        values,
-        height=4,
-        width=6,
-        n_ticks=4,
-        tick_width=0.2,
-        label_y_axis=True,
-        y_axis_label_height=0.25,
-        max_value=1,
+        values: Iterable[float],
+        height: float = 4,
+        width: float = 6,
+        n_ticks: int = 4,
+        tick_width: float = 0.2,
+        label_y_axis: bool = True,
+        y_axis_label_height: float = 0.25,
+        max_value: float = 1,
         bar_colors=[BLUE, YELLOW],
-        bar_fill_opacity=0.8,
-        bar_stroke_width=3,
-        bar_names=[],
-        bar_label_scale_val=0.75,
+        bar_fill_opacity: float = 0.8,
+        bar_stroke_width: float = 3,
+        bar_names: List[str] = [],
+        bar_label_scale_val: float = 0.75,
         **kwargs
-    ):
+    ):  # What's the return type?
         VGroup.__init__(self, **kwargs)
         self.n_ticks = n_ticks
         self.tick_width = tick_width
@@ -184,19 +266,21 @@ class BarChart(VGroup):
         self.bar_stroke_width = bar_stroke_width
         self.bar_names = bar_names
         self.bar_label_scale_val = bar_label_scale_val
+        self.total_bar_width = width
+        self.total_bar_height = height
 
         if self.max_value is None:
             self.max_value = max(values)
 
-        self.add_axes(width, height)
-        self.add_bars(values, width, height)
+        self.add_axes()
+        self.add_bars(values)
         self.center()
 
-    def add_axes(self, width, height):
-        x_axis = Line(self.tick_width * LEFT / 2, width * RIGHT)
-        y_axis = Line(MED_LARGE_BUFF * DOWN, height * UP)
+    def add_axes(self):
+        x_axis = Line(self.tick_width * LEFT / 2, self.total_bar_width * RIGHT)
+        y_axis = Line(MED_LARGE_BUFF * DOWN, self.total_bar_height * UP)
         ticks = VGroup()
-        heights = np.linspace(0, height, self.n_ticks + 1)
+        heights = np.linspace(0, self.total_bar_height, self.n_ticks + 1)
         values = np.linspace(0, self.max_value, self.n_ticks + 1)
         for y, _value in zip(heights, values):
             tick = Line(LEFT, RIGHT)
@@ -218,12 +302,12 @@ class BarChart(VGroup):
             self.y_axis_labels = labels
             self.add(labels)
 
-    def add_bars(self, values, width, height):
-        buff = float(width) / (2 * len(values) + 1)
+    def add_bars(self, values):
+        buff = float(self.total_bar_width) / (2 * len(values) + 1)
         bars = VGroup()
         for i, value in enumerate(values):
             bar = Rectangle(
-                height=(value / self.max_value) * height,
+                height=(value / self.max_value) * self.total_bar_height,
                 width=buff,
                 stroke_width=self.bar_stroke_width,
                 fill_opacity=self.bar_fill_opacity,
@@ -246,5 +330,5 @@ class BarChart(VGroup):
     def change_bar_values(self, values):
         for bar, value in zip(self.bars, values):
             bar_bottom = bar.get_bottom()
-            bar.stretch_to_fit_height((value / self.max_value) * self.height)
+            bar.stretch_to_fit_height((value / self.max_value) * self.total_bar_height)
             bar.move_to(bar_bottom, DOWN)
