@@ -16,9 +16,9 @@ from ...constants import *
 from ...mobject.geometry import Arc, Line
 from ...mobject.svg.svg_path import SVGPathMobject
 from ...mobject.svg.tex_mobject import MathTex, Tex
-from ...mobject.types.opengl_vectorized_mobject import OpenGLVMobject
 from ...mobject.types.vectorized_mobject import VMobject
 from ...utils.color import BLACK
+from ...utils.deprecation import deprecated_params
 
 
 class Brace(SVGPathMobject):
@@ -68,7 +68,21 @@ class Brace(SVGPathMobject):
         background_stroke_color=BLACK,
         **kwargs
     ):
-        path_string_template = "m0.01216 0c-0.01152 0-0.01216 6.103e-4 -0.01216 0.01311v0.007762c0.06776 0.122 0.1799 0.1455 0.2307 0.1455h{0}c0.03046 3.899e-4 0.07964 0.00449 0.1246 0.02636 0.0537 0.02695 0.07418 0.05816 0.08648 0.07769 0.001562 0.002538 0.004539 0.002563 0.01098 0.002563 0.006444-2e-8 0.009421-2.47e-5 0.01098-0.002563 0.0123-0.01953 0.03278-0.05074 0.08648-0.07769 0.04491-0.02187 0.09409-0.02597 0.1246-0.02636h{0}c0.05077 0 0.1629-0.02346 0.2307-0.1455v-0.007762c-1.78e-6 -0.0125-6.365e-4 -0.01311-0.01216-0.01311-0.006444-3.919e-8 -0.009348 2.448e-5 -0.01091 0.002563-0.0123 0.01953-0.03278 0.05074-0.08648 0.07769-0.04491 0.02187-0.09416 0.02597-0.1246 0.02636h{1}c-0.04786 0-0.1502 0.02094-0.2185 0.1256-0.06833-0.1046-0.1706-0.1256-0.2185-0.1256h{1}c-0.03046-3.899e-4 -0.07972-0.004491-0.1246-0.02636-0.0537-0.02695-0.07418-0.05816-0.08648-0.07769-0.001562-0.002538-0.004467-0.002563-0.01091-0.002563z"
+        path_string_template = (
+            "m0.01216 0c-0.01152 0-0.01216 6.103e-4 -0.01216 0.01311v0.007762c0.06776 "
+            "0.122 0.1799 0.1455 0.2307 0.1455h{0}c0.03046 3.899e-4 0.07964 0.00449 "
+            "0.1246 0.02636 0.0537 0.02695 0.07418 0.05816 0.08648 0.07769 0.001562 "
+            "0.002538 0.004539 0.002563 0.01098 0.002563 0.006444-2e-8 0.009421-2.47e-"
+            "5 0.01098-0.002563 0.0123-0.01953 0.03278-0.05074 0.08648-0.07769 0.04491"
+            "-0.02187 0.09409-0.02597 0.1246-0.02636h{0}c0.05077 0 0.1629-0.02346 "
+            "0.2307-0.1455v-0.007762c-1.78e-6 -0.0125-6.365e-4 -0.01311-0.01216-0.0131"
+            "1-0.006444-3.919e-8 -0.009348 2.448e-5 -0.01091 0.002563-0.0123 0.01953-"
+            "0.03278 0.05074-0.08648 0.07769-0.04491 0.02187-0.09416 0.02597-0.1246 "
+            "0.02636h{1}c-0.04786 0-0.1502 0.02094-0.2185 0.1256-0.06833-0.1046-0.1706"
+            "-0.1256-0.2185-0.1256h{1}c-0.03046-3.899e-4 -0.07972-0.004491-0.1246-0.02"
+            "636-0.0537-0.02695-0.07418-0.05816-0.08648-0.07769-0.001562-0.002538-"
+            "0.004467-0.002563-0.01091-0.002563z"
+        )
         default_min_width = 0.90552
 
         self.buff = buff
@@ -134,33 +148,44 @@ class Brace(SVGPathMobject):
 
 
 class BraceLabel(VMobject, metaclass=ConvertToOpenGL):
+    @deprecated_params(
+        params="label_scale",
+        since="v0.10.0",
+        until="v0.11.0",
+        message="Use font_size instead. To convert old scale factors to font size, multiply by 48.",
+    )
     def __init__(
         self,
         obj,
         text,
         brace_direction=DOWN,
         label_constructor=MathTex,
-        label_scale=1,
+        font_size=DEFAULT_FONT_SIZE,
+        buff=0.2,
         **kwargs
     ):
+        label_scale = kwargs.pop("label_scale", None)
+        if label_scale:
+            self.font_size = label_scale * DEFAULT_FONT_SIZE
+        else:
+            self.font_size = font_size
+
         self.label_constructor = label_constructor
-        self.label_scale = label_scale
         super().__init__(**kwargs)
 
         self.brace_direction = brace_direction
+        self.buff = buff
         if isinstance(obj, list):
             obj = self.get_group_class()(*obj)
-        self.brace = Brace(obj, brace_direction, **kwargs)
+        self.brace = Brace(obj, brace_direction, buff, **kwargs)
 
         if isinstance(text, tuple) or isinstance(text, list):
-            self.label = self.label_constructor(*text, **kwargs)
+            self.label = self.label_constructor(font_size=font_size, *text, **kwargs)
         else:
-            self.label = self.label_constructor(str(text))
-        if self.label_scale != 1:
-            self.label.scale(self.label_scale)
+            self.label = self.label_constructor(str(text), font_size=font_size)
 
         self.brace.put_at_tip(self.label)
-        self.submobjects = [self.brace, self.label]
+        self.add(self.brace, self.label)
 
     def creation_anim(self, label_anim=FadeIn, brace_anim=GrowFromCenter):
         return AnimationGroup(brace_anim(self.brace), label_anim(self.label))
@@ -170,21 +195,17 @@ class BraceLabel(VMobject, metaclass=ConvertToOpenGL):
             obj = self.get_group_class()(*obj)
         self.brace = Brace(obj, self.brace_direction, **kwargs)
         self.brace.put_at_tip(self.label)
-        self.submobjects[0] = self.brace
         return self
 
     def change_label(self, *text, **kwargs):
         self.label = self.label_constructor(*text, **kwargs)
-        if self.label_scale != 1:
-            self.label.scale(self.label_scale)
 
         self.brace.put_at_tip(self.label)
-        self.submobjects[1] = self.label
         return self
 
-    def change_brace_label(self, obj, *text):
+    def change_brace_label(self, obj, *text, **kwargs):
         self.shift_brace(obj)
-        self.change_label(*text)
+        self.change_label(*text, **kwargs)
         return self
 
 
@@ -248,9 +269,13 @@ class ArcBrace(Brace):
         The :class:`ArcBrace` is smaller for arcs with smaller radii.
 
     .. note::
-        The :class:`ArcBrace` is initially a vertical :class:`Brace` defined by the length of the :class:`~.Arc`, but is scaled down to match the start and end angles. An exponential function is then applied after it is shifted based on the radius of the arc.
+        The :class:`ArcBrace` is initially a vertical :class:`Brace` defined by the
+        length of the :class:`~.Arc`, but is scaled down to match the start and end
+        angles. An exponential function is then applied after it is shifted based on
+        the radius of the arc.
 
-        The scaling effect is not applied for arcs with radii smaller than 1 to prevent over-scaling.
+        The scaling effect is not applied for arcs with radii smaller than 1 to prevent
+        over-scaling.
 
     Parameters
     ----------
