@@ -1,191 +1,13 @@
 r"""Mobjects representing text rendered using LaTeX.
 
+.. important::
+
+   See the corresponding tutorial :ref:`rendering-with-latex`
+
 .. note::
+
    Just as you can use :class:`~.Text` (from the module :mod:`~.text_mobject`) to add text to your videos, you can use :class:`~.Tex` and :class:`~.MathTex` to insert LaTeX.
 
-The Tex mobject
-+++++++++++++++
-
-.. manim:: HelloLaTeX
-    :save_last_frame:
-
-    class HelloLaTeX(Scene):
-        def construct(self):
-            tex = Tex(r'\LaTeX').scale(3)
-            self.add(tex)
-
-Note that we are using a raw string (``r'---'``) instead of a regular string (``'---'``).
-This is because TeX code uses a lot of special characters - like ``\`` for example -
-that have special meaning within a regular python string. An alternative would have
-been to write ``\\`` as in ``Tex('\\LaTeX')``.
-
-The MathTex mobject
-+++++++++++++++++++
-Anything enclosed in ``$`` signs is interpreted as maths-mode:
-
-.. manim:: HelloTex
-    :save_last_frame:
-
-    class HelloTex(Scene):
-        def construct(self):
-            tex = Tex(r'$\xrightarrow{x^2y^3}$ \LaTeX').scale(3)
-            self.add(tex)
-
-Whereas in a :class:`~.MathTex` mobject everything is math-mode by default.
-
-.. manim:: MovingBraces
-
-    class MovingBraces(Scene):
-        def construct(self):
-            text=MathTex(
-                "\\frac{d}{dx}f(x)g(x)=",       #0
-                "f(x)\\frac{d}{dx}g(x)",        #1
-                "+",                            #2
-                "g(x)\\frac{d}{dx}f(x)"         #3
-            )
-            self.play(Write(text))
-            brace1 = Brace(text[1], UP, buff=SMALL_BUFF)
-            brace2 = Brace(text[3], UP, buff=SMALL_BUFF)
-            t1 = brace1.get_text("$g'f$")
-            t2 = brace2.get_text("$f'g$")
-            self.play(
-                GrowFromCenter(brace1),
-                FadeIn(t1),
-                )
-            self.wait()
-            self.play(
-                ReplacementTransform(brace1,brace2),
-                ReplacementTransform(t1,t2)
-                )
-            self.wait()
-
-
-LaTeX commands and keyword arguments
-++++++++++++++++++++++++++++++++++++
-We can use any standard LaTeX commands in the AMS maths packages. For example the ``mathtt`` math-text type, or the ``looparrowright`` arrow.
-
-.. manim:: AMSLaTeX
-    :save_last_frame:
-
-    class AMSLaTeX(Scene):
-        def construct(self):
-            tex = Tex(r'$\mathtt{H} \looparrowright$ \LaTeX').scale(3)
-            self.add(tex)
-
-On the manim side, the :class:`~.Tex` class also accepts attributes to change the appearance of the output.
-This is very similar to the :class:`~.Text` class. For example, the ``color`` keyword changes the color of the TeX mobject:
-
-.. manim:: LaTeXAttributes
-    :save_last_frame:
-
-    class LaTeXAttributes(Scene):
-        def construct(self):
-            tex = Tex(r'Hello \LaTeX', color=BLUE).scale(3)
-            self.add(tex)
-
-Extra LaTeX Packages
-++++++++++++++++++++
-Some commands require special packages to be loaded into the TeX template. For example,
-to use the ``mathscr`` script, we need to add the ``mathrsfs`` package. Since this package isn't loaded
-into manim's tex template by default, we add it manually:
-
-.. manim:: AddPackageLatex
-    :save_last_frame:
-
-    class AddPackageLatex(Scene):
-        def construct(self):
-            myTemplate = TexTemplate()
-            myTemplate.add_to_preamble(r"\usepackage{mathrsfs}")
-            tex = Tex(r'$\mathscr{H} \rightarrow \mathbb{H}$}', tex_template=myTemplate).scale(3)
-            self.add(tex)
-
-Substrings and parts
-++++++++++++++++++++
-The TeX mobject can accept multiple strings as arguments. Afterwards you can refer to the individual
-parts either by their index (like ``tex[1]``), or you can look them up by (parts of) the tex code like
-in this example where we set the color of the ``\bigstar`` using :func:`~.set_color_by_tex`:
-
-.. manim:: LaTeXSubstrings
-    :save_last_frame:
-
-    class LaTeXSubstrings(Scene):
-        def construct(self):
-            tex = Tex('Hello', r'$\bigstar$', r'\LaTeX').scale(3)
-            tex.set_color_by_tex('igsta', RED)
-            self.add(tex)
-
-Note that :func:`~.set_color_by_tex` colors the entire substring containing the Tex searched for,
-not just the specific symbol or Tex expression searched for. Consider the following example:
-
-.. manim:: IncorrectLaTeXSubstringColoring
-    :save_last_frame:
-
-    class IncorrectLaTeXSubstringColoring(Scene):
-        def construct(self):
-            equation = MathTex(
-                r"e^x = x^0 + x^1 + \frac{1}{2} x^2 + \frac{1}{6} x^3 + \cdots + \frac{1}{n!} x^n + \cdots"
-            )
-            equation.set_color_by_tex("x", YELLOW)
-            self.add(equation)
-
-As you can see, this colors the entire equation yellow, contrary to what may be expected. To color only ``x`` yellow, we have to do the following:
-
-.. manim:: CorrectLaTeXSubstringColoring
-    :save_last_frame:
-
-    class CorrectLaTeXSubstringColoring(Scene):
-        def construct(self):
-            equation = MathTex(
-                r"e^x = x^0 + x^1 + \frac{1}{2} x^2 + \frac{1}{6} x^3 + \cdots + \frac{1}{n!} x^n + \cdots",
-                substrings_to_isolate="x"
-            )
-            equation.set_color_by_tex("x", YELLOW)
-            self.add(equation)
-
-By setting ``substring_to_isolate`` to ``x``, we split up the :class:`~.MathTex` into substrings
-automatically and isolate ``x`` components into individual substrings. Only then can :meth:`~.set_color_by_tex` be used to achieve the desired result.
-
-LaTeX Maths Fonts - The Template Library
-++++++++++++++++++++++++++++++++++++++++
-Changing fonts in LaTeX when typesetting mathematical formulae is a little bit more tricky than
-with regular text. It requires changing the template that is used to compile the tex code.
-Manim comes with a collection of :class:`~.TexFontTemplates` ready for you to use. These templates will all work
-in maths mode:
-
-.. manim:: LaTeXMathFonts
-    :save_last_frame:
-
-    class LaTeXMathFonts(Scene):
-        def construct(self):
-            tex = Tex(r'$x^2 + y^2 = z^2$', tex_template=TexFontTemplates.french_cursive).scale(3)
-            self.add(tex)
-
-Manim also has a :class:`~.TexTemplateLibrary` containing the TeX templates used by 3Blue1Brown. One example
-is the ctex template, used for typesetting Chinese. For this to work, the ctex LaTeX package
-must be installed on your system. Furthermore, if you are only typesetting Text, you probably do not
-need :class:`~.Tex` at all, and should use :class:`~.Text` or :class:`~.PangoText` instead.
-
-.. manim:: LaTeXTemplateLibrary
-    :save_last_frame:
-
-    class LaTeXTemplateLibrary(Scene):
-        def construct(self):
-            tex = Tex('Hello 你好 \\LaTeX', tex_template=TexTemplateLibrary.ctex).scale(3)
-            self.add(tex)
-
-
-Aligning formulae
-+++++++++++++++++
-A :class:`~.MathTex` mobject is typeset in the LaTeX  ``align*`` environment. This means you can use the ``&`` alignment
-character when typesetting multiline formulae:
-
-.. manim:: LaTeXAlignEnvironment
-    :save_last_frame:
-
-    class LaTeXAlignEnvironment(Scene):
-        def construct(self):
-            tex = MathTex(r'f(x) &= 3 + 2 + 1\\ &= 5 + 1 \\ &= 6').scale(2)
-            self.add(tex)
 """
 
 __all__ = [
@@ -204,18 +26,23 @@ import re
 from functools import reduce
 from textwrap import dedent
 
+from colour import Color
+
 from ... import config, logger
 from ...constants import *
 from ...mobject.geometry import Line
 from ...mobject.svg.svg_mobject import SVGMobject
 from ...mobject.svg.svg_path import SVGPathMobject
 from ...mobject.types.vectorized_mobject import VectorizedPoint, VGroup
-from ...utils.color import BLACK
+from ...utils.color import BLACK, WHITE
+from ...utils.deprecation import deprecated_params
 from ...utils.tex import TexTemplate
 from ...utils.tex_file_writing import tex_to_svg_file
 from .style_utils import parse_style
 
-TEX_MOB_SCALE_FACTOR = 0.05
+SCALE_FACTOR_PER_FONT_POINT = 1 / 960
+
+tex_string_to_mob_map = {}
 
 
 class TexSymbol(SVGPathMobject):
@@ -247,8 +74,12 @@ class SingleStringMathTex(SVGMobject):
         organize_left_to_right=False,
         tex_environment="align*",
         tex_template=None,
+        font_size=DEFAULT_FONT_SIZE,
+        color=Color(WHITE),
         **kwargs,
     ):
+
+        self._font_size = font_size
         self.organize_left_to_right = organize_left_to_right
         self.tex_environment = tex_environment
         if tex_template is None:
@@ -262,8 +93,7 @@ class SingleStringMathTex(SVGMobject):
             environment=self.tex_environment,
             tex_template=self.tex_template,
         )
-        SVGMobject.__init__(
-            self,
+        super().__init__(
             file_name=file_name,
             should_center=should_center,
             stroke_width=stroke_width,
@@ -273,16 +103,38 @@ class SingleStringMathTex(SVGMobject):
             background_stroke_color=background_stroke_color,
             should_subdivide_sharp_curves=True,
             should_remove_null_curves=True,
+            color=color,
             **kwargs,
         )
+        # used for scaling via font_size.setter
+        self.initial_height = self.height
+
         if height is None:
-            self.scale(TEX_MOB_SCALE_FACTOR)
+            self.font_size = self._font_size
+
         if self.organize_left_to_right:
             self.organize_submobjects_left_to_right()
 
     def __repr__(self):
         return f"{type(self).__name__}({repr(self.tex_string)})"
 
+    @property
+    def font_size(self):
+        """The font size of the tex mobject."""
+        return self.height / self.initial_height / SCALE_FACTOR_PER_FONT_POINT
+
+    @font_size.setter
+    def font_size(self, font_val):
+        if font_val <= 0:
+            raise ValueError("font_size must be greater than 0.")
+        elif self.height > 0:
+            # sometimes manim generates a SingleStringMathex mobject with 0 height.
+            # can't be scaled regardless and will error without the elif.
+
+            # scale to a factor of the initial height so that setting
+            # font_size does not depend on current size.
+            self.scale(font_val / self.font_size)
+
     def get_modified_expression(self, tex_string):
         result = tex_string
         result = result.strip()
@@ -322,10 +174,10 @@ class SingleStringMathTex(SVGMobject):
             tex = tex.replace("\\\\", "\\quad\\\\")
 
         # Handle imbalanced \left and \right
-        num_lefts, num_rights = [
+        num_lefts, num_rights = (
             len([s for s in tex.split(substr)[1:] if s and s[0] in "(){}[]|.\\"])
             for substr in ("\\left", "\\right")
-        ]
+        )
         if num_lefts != num_rights:
             tex = tex.replace("\\left", "\\big")
             tex = tex.replace("\\right", "\\big")
@@ -427,12 +279,10 @@ class MathTex(SingleStringMathTex):
             self.tex_to_color_map = {}
         self.tex_environment = tex_environment
         self.brace_notation_split_occurred = False
-        tex_strings = self.break_up_tex_strings(tex_strings)
-        self.tex_strings = tex_strings
+        self.tex_strings = self.break_up_tex_strings(tex_strings)
         try:
-            SingleStringMathTex.__init__(
-                self,
-                self.arg_separator.join(tex_strings),
+            super().__init__(
+                self.arg_separator.join(self.tex_strings),
                 tex_environment=self.tex_environment,
                 tex_template=self.tex_template,
                 **kwargs,
@@ -471,7 +321,7 @@ class MathTex(SingleStringMathTex):
         patterns = []
         patterns.extend(
             [
-                "({})".format(re.escape(ss))
+                f"({re.escape(ss)})"
                 for ss in it.chain(
                     self.substrings_to_isolate, self.tex_to_color_map.keys()
                 )
@@ -508,20 +358,14 @@ class MathTex(SingleStringMathTex):
                 # For cases like empty tex_strings, we want the corresponding
                 # part of the whole MathTex to be a VectorizedPoint
                 # positioned in the right part of the MathTex
-                sub_tex_mob.submobjects = [VectorizedPoint()]
-                if config.renderer == "opengl":
-                    sub_tex_mob.assemble_family()
+                sub_tex_mob.set_submobjects([VectorizedPoint()])
                 last_submob_index = min(curr_index, len(self.submobjects) - 1)
                 sub_tex_mob.move_to(self.submobjects[last_submob_index], RIGHT)
             else:
-                sub_tex_mob.submobjects = self.submobjects[curr_index:new_index]
-                if config.renderer == "opengl":
-                    sub_tex_mob.assemble_family()
+                sub_tex_mob.set_submobjects(self.submobjects[curr_index:new_index])
             new_submobjects.append(sub_tex_mob)
             curr_index = new_index
-        self.submobjects = new_submobjects
-        if config.renderer == "opengl":
-            self.assemble_family()
+        self.set_submobjects(new_submobjects)
         return self
 
     def get_parts_by_tex(self, tex, substring=True, case_sensitive=True):
@@ -534,7 +378,7 @@ class MathTex(SingleStringMathTex):
             else:
                 return tex1 == tex2
 
-        return VGroup(*[m for m in self.submobjects if test(tex, m.get_tex_string())])
+        return VGroup(*(m for m in self.submobjects if test(tex, m.get_tex_string())))
 
     def get_part_by_tex(self, tex, **kwargs):
         all_parts = self.get_parts_by_tex(tex, **kwargs)
@@ -588,8 +432,7 @@ class Tex(MathTex):
     def __init__(
         self, *tex_strings, arg_separator="", tex_environment="center", **kwargs
     ):
-        MathTex.__init__(
-            self,
+        super().__init__(
             *tex_strings,
             arg_separator=arg_separator,
             tex_environment=tex_environment,
@@ -598,6 +441,22 @@ class Tex(MathTex):
 
 
 class BulletedList(Tex):
+    """
+    Examples
+    --------
+
+    .. manim:: BulletedListExample
+        :save_last_frame:
+
+        class BulletedListExample(Scene):
+            def construct(self):
+                blist = BulletedList("Item 1", "Item 2", "Item 3", height=2, width=2)
+                blist.set_color_by_tex("Item 1", RED)
+                blist.set_color_by_tex("Item 2", GREEN)
+                blist.set_color_by_tex("Item 3", BLUE)
+                self.add(blist)
+    """
+
     def __init__(
         self,
         *items,
@@ -610,8 +469,8 @@ class BulletedList(Tex):
         self.dot_scale_factor = dot_scale_factor
         self.tex_environment = tex_environment
         line_separated_items = [s + "\\\\" for s in items]
-        Tex.__init__(
-            self, *line_separated_items, tex_environment=tex_environment, **kwargs
+        super().__init__(
+            *line_separated_items, tex_environment=tex_environment, **kwargs
         )
         for part in self:
             dot = MathTex("\\cdot").scale(self.dot_scale_factor)
@@ -651,21 +510,28 @@ class Title(Tex):
 
     """
 
+    @deprecated_params(
+        params="scale_factor",
+        since="v0.10.0",
+        until="v0.11.0",
+        message="Use font_size instead. To convert old scale factors to font size, multiply by 48.",
+    )
     def __init__(
         self,
         *text_parts,
-        scale_factor=1,
         include_underline=True,
         match_underline_width_to_text=False,
         underline_buff=MED_SMALL_BUFF,
         **kwargs,
     ):
-        self.scale_factor = scale_factor
+        scale_factor = kwargs.pop("scale_factor", None)
+        if scale_factor:
+            kwargs["font_size"] = DEFAULT_FONT_SIZE * scale_factor
+
         self.include_underline = include_underline
         self.match_underline_width_to_text = match_underline_width_to_text
         self.underline_buff = underline_buff
-        Tex.__init__(self, *text_parts, **kwargs)
-        self.scale(self.scale_factor)
+        super().__init__(*text_parts, **kwargs)
         self.to_edge(UP)
         if self.include_underline:
             underline_width = config["frame_width"] - 2
