@@ -1,7 +1,12 @@
 """Mobjects used for displaying (non-LaTeX) text.
 
 .. note::
-   Just as you can use :class:`~.Tex` and :class:`~.MathTex` (from the module :mod:`~.tex_mobject`) to insert LaTeX to your videos, you can use :class:`~.Text` to to add normal text.
+   Just as you can use :class:`~.Tex` and :class:`~.MathTex` (from the module :mod:`~.tex_mobject`)
+   to insert LaTeX to your videos, you can use :class:`~.Text` to to add normal text.
+
+.. important::
+
+   See the corresponding tutorial :ref:`rendering-with-latex`
 
 
 The simplest way to add text to your animations is to use the :class:`~.Text` class. It uses the Pango library to render text.
@@ -49,13 +54,13 @@ import copy
 import hashlib
 import os
 import re
-import typing
 from contextlib import contextmanager
 from pathlib import Path
-from typing import Dict
+from typing import Dict, Union
 
 import manimpango
 import numpy as np
+from colour import Color
 from manimpango import MarkupUtils, PangoUtils, TextSetting
 
 from ... import config, logger
@@ -64,12 +69,15 @@ from ...mobject.geometry import Dot
 from ...mobject.svg.svg_mobject import SVGMobject
 from ...mobject.types.vectorized_mobject import VGroup
 from ...utils.color import WHITE, Colors
+from ...utils.deprecation import deprecated_params
 
 TEXT_MOB_SCALE_FACTOR = 0.05
+DEFAULT_LINE_SPACING_SCALE = 0.3
+TEXT2SVG_ADJUSTMENT_FACTOR = 4.8
 
 
 def remove_invisible_chars(mobject):
-    """Function to remove unwanted invisible characters from some mobject
+    """Function to remove unwanted invisible characters from some mobjects.
 
     Parameters
     ----------
@@ -93,9 +101,9 @@ def remove_invisible_chars(mobject):
     if mobject[0].__class__ == VGroup:
         for i in range(mobject.__len__()):
             mobject_without_dots.add(VGroup())
-            mobject_without_dots[i].add(*[k for k in mobject[i] if k.__class__ != Dot])
+            mobject_without_dots[i].add(*(k for k in mobject[i] if k.__class__ != Dot))
     else:
-        mobject_without_dots.add(*[k for k in mobject if k.__class__ != Dot])
+        mobject_without_dots.add(*(k for k in mobject if k.__class__ != Dot))
     if iscode:
         code.code = mobject_without_dots
         return code
@@ -136,7 +144,7 @@ class Paragraph(VGroup):
     def __init__(self, *text, line_spacing=-1, alignment=None, **config):
         self.line_spacing = line_spacing
         self.alignment = alignment
-        VGroup.__init__(self, **config)
+        super().__init__()
 
         lines_str = "\n".join(list(text))
         self.lines_text = Text(lines_str, line_spacing=line_spacing, **config)
@@ -165,9 +173,7 @@ class Paragraph(VGroup):
         self.lines[1].extend(
             [self.alignment for _ in range(chars_lines_text_list.__len__())]
         )
-        self.get_group_class().__init__(
-            self, *[self.lines[0][i] for i in range(self.lines[0].__len__())], **config
-        )
+        self.add(*self.lines[0])
         self.move_to(np.array([0, 0, 0]))
         if self.alignment:
             self.set_all_lines_alignments(self.alignment)
@@ -358,17 +364,17 @@ class Text(SVGMobject):
         class MultipleFonts(Scene):
             def construct(self):
                 morning = Text("வணக்கம்", font="sans-serif")
-                chin = Text(
-                    "見 角 言 谷  辛 辰 辵 邑 酉 釆 里!", t2c={"見 角 言": BLUE}
+                japanese = Text(
+                    "日本へようこそ", t2c={"日本": BLUE}
                 )  # works same as ``Text``.
-                mess = Text("Multi-Language", style=BOLD)
+                mess = Text("Multi-Language", weight=BOLD)
                 russ = Text("Здравствуйте मस नम म ", font="sans-serif")
                 hin = Text("नमस्ते", font="sans-serif")
                 arb = Text(
                     "صباح الخير \n تشرفت بمقابلتك", font="sans-serif"
                 )  # don't mix RTL and LTR languages nothing shows up then ;-)
-                japanese = Text("臂猿「黛比」帶著孩子", font="sans-serif")
-                self.add(morning,chin,mess,russ,hin,arb,japanese)
+                chinese = Text("臂猿「黛比」帶著孩子", font="sans-serif")
+                self.add(morning, japanese, mess, russ, hin, arb, chinese)
                 for i,mobj in enumerate(self.mobjects):
                     mobj.shift(DOWN*(i-3))
 
@@ -392,13 +398,19 @@ class Text(SVGMobject):
 
     """
 
+    @deprecated_params(
+        params="size",
+        since="v0.10.0",
+        until="v0.11.0",
+        message="Use font_size instead. To convert old scale factors to font size, multiply by 48.",
+    )
     def __init__(
         self,
         text: str,
         fill_opacity: float = 1.0,
-        stroke_width: int = 0,
-        color: str = WHITE,
-        size: int = 1,
+        stroke_width: float = 0,
+        color: Color = WHITE,
+        font_size: float = DEFAULT_FONT_SIZE,
         line_spacing: int = -1,
         font: str = "",
         slant: str = NORMAL,
@@ -418,7 +430,14 @@ class Text(SVGMobject):
         disable_ligatures: bool = False,
         **kwargs,
     ):
-        self.size = size
+        # deprecation
+        size = kwargs.pop("size", None)
+        if size is not None:
+            self._font_size = size * DEFAULT_FONT_SIZE
+        else:
+            # needs to be a float or else size is inflated when font_size = 24 (unknown cause)
+            self._font_size = float(font_size)
+
         self.line_spacing = line_spacing
         self.font = font
         self.slant = slant
@@ -454,13 +473,14 @@ class Text(SVGMobject):
             text_without_tabs = text.replace("\t", " " * self.tab_width)
         self.text = text_without_tabs
         if self.line_spacing == -1:
-            self.line_spacing = self.size + self.size * 0.3
+            self.line_spacing = (
+                self._font_size + self._font_size * DEFAULT_LINE_SPACING_SCALE
+            )
         else:
-            self.line_spacing = self.size + self.size * self.line_spacing
+            self.line_spacing = self._font_size + self._font_size * self.line_spacing
         file_name = self.text2svg()
         PangoUtils.remove_last_M(file_name)
-        SVGMobject.__init__(
-            self,
+        super().__init__(
             file_name,
             color=color,
             fill_opacity=fill_opacity,
@@ -473,7 +493,10 @@ class Text(SVGMobject):
         )
         self.text = text
         if self.disable_ligatures:
-            self.submobjects = [*self.gen_chars()]
+            if config.renderer == "opengl":
+                self.set_submobjects(self.gen_chars())
+            else:
+                self.submobjects = [*self.gen_chars()]
         self.chars = self.get_group_class()(*self.submobjects)
         self.text = text_without_tabs.replace(" ", "").replace("\n", "")
         if config.renderer == "opengl":
@@ -505,10 +528,30 @@ class Text(SVGMobject):
         # anti-aliasing
         if height is None and width is None:
             self.scale(TEXT_MOB_SCALE_FACTOR)
+        self.initial_height = self.height
 
     def __repr__(self):
         return f"Text({repr(self.original_text)})"
 
+    @property
+    def font_size(self):
+        return (
+            self.height
+            / self.initial_height
+            / TEXT_MOB_SCALE_FACTOR
+            * 2.4
+            * self._font_size
+            / DEFAULT_FONT_SIZE
+        )
+
+    @font_size.setter
+    def font_size(self, font_val):
+        # TODO: use pango's font size scaling.
+        if font_val <= 0:
+            raise ValueError("font_size must be greater than 0.")
+        else:
+            self.scale(font_val / self.font_size)
+
     def gen_chars(self):
         chars = self.get_group_class()()
         submobjects_char_index = 0
@@ -585,7 +628,7 @@ class Text(SVGMobject):
             "PANGO" + self.font + self.slant + self.weight
         )  # to differentiate Text and CairoText
         settings += str(self.t2f) + str(self.t2s) + str(self.t2w)
-        settings += str(self.line_spacing) + str(self.size)
+        settings += str(self.line_spacing) + str(self._font_size)
         settings += str(self.disable_ligatures)
         id_str = self.text + settings
         hasher = hashlib.sha256()
@@ -638,35 +681,39 @@ class Text(SVGMobject):
         return settings
 
     def text2svg(self):
-        """Internally used function.
-        Convert the text to SVG using Pango
-        """
-        size = self.size * 10
-        line_spacing = self.line_spacing * 10
+        """Convert the text to SVG using Pango."""
+        size = self._font_size
+        line_spacing = self.line_spacing
+        size /= TEXT2SVG_ADJUSTMENT_FACTOR
+        line_spacing /= TEXT2SVG_ADJUSTMENT_FACTOR
+
         dir_name = config.get_dir("text_dir")
-        disable_liga = self.disable_ligatures
         if not os.path.exists(dir_name):
             os.makedirs(dir_name)
         hash_name = self.text2hash()
         file_name = os.path.join(dir_name, hash_name) + ".svg"
-        if os.path.exists(file_name):
-            return file_name
-        settings = self.text2settings()
-        width = 600
-        height = 400
 
-        return manimpango.text2svg(
-            settings,
-            size,
-            line_spacing,
-            disable_liga,
-            file_name,
-            START_X,
-            START_Y,
-            width,
-            height,
-            self.text,
-        )
+        if os.path.exists(file_name):
+            svg_file = file_name
+        else:
+            settings = self.text2settings()
+            width = config["pixel_width"]
+            height = config["pixel_height"]
+
+            svg_file = manimpango.text2svg(
+                settings,
+                size,
+                line_spacing,
+                self.disable_ligatures,
+                file_name,
+                START_X,
+                START_Y,
+                width,
+                height,
+                self.text,
+            )
+
+        return svg_file
 
     def init_colors(self, propagate_colors=True):
         super().init_colors(propagate_colors=propagate_colors)
@@ -676,8 +723,51 @@ class MarkupText(SVGMobject):
     r"""Display (non-LaTeX) text rendered using `Pango <https://pango.gnome.org/>`_.
 
     Text objects behave like a :class:`.VGroup`-like iterable of all characters
-    in the given text. In particular, slicing is possible. Text can be formatted
-    using different tags:
+    in the given text. In particular, slicing is possible.
+
+    **What is PangoMarkup?**
+
+    PangoMarkup is a small markup language like html and it helps you avoid using
+    "range of characters" while coloring or styling a piece a Text. You can use
+    this language with :class:`~.MarkupText`.
+
+    A simple example of a marked-up string might be::
+
+        <span foreground="blue" size="x-large">Blue text</span> is <i>cool</i>!"
+
+    and it can be used with :class:`~.MarkupText` as
+
+    .. manim:: MarkupExample
+        :save_last_frame:
+
+        class MarkupExample(Scene):
+            def construct(self):
+                text = MarkupText('<span foreground="blue" size="x-large">Blue text</span> is <i>cool</i>!"')
+                self.add(text)
+
+    A more elaborate example would be:
+
+    .. manim:: MarkupElaborateExample
+        :save_last_frame:
+
+        class MarkupElaborateExample(Scene):
+            def construct(self):
+                text = MarkupText(
+                    '<span foreground="purple">ا</span><span foreground="red">َ</span>'
+                    'ل<span foreground="blue">ْ</span>ع<span foreground="red">َ</span>ر'
+                    '<span foreground="red">َ</span>ب<span foreground="red">ِ</span>ي'
+                    '<span foreground="green">ّ</span><span foreground="red">َ</span>ة'
+                    '<span foreground="blue">ُ</span>'
+                )
+                self.add(text)
+
+    PangoMarkup can also contain XML features such as numeric character
+    entities such as ``&#169;`` for © can be used too.
+
+    The most general markup tag is ``<span>``, then there are some
+    convenience tags.
+
+    Here is a list of supported tags:
 
     - ``<b>bold</b>``, ``<i>italic</i>`` and ``<b><i>bold+italic</i></b>``
     - ``<ul>underline</ul>`` and ``<s>strike through</s>``
@@ -693,18 +783,27 @@ class MarkupText(SVGMobject):
     - ``<span fgcolor="red">temporary change of color</span>``
     - ``<gradient from="YELLOW" to="RED">temporary gradient</gradient>``
 
-    For ``<span>`` markup, colors can be specified either as hex triples like ``#aabbcc`` or as named CSS colors like ``AliceBlue``.
-    The ``<gradient>`` tag being handled by Manim rather than Pango, supports hex triplets or Manim constants like ``RED`` or ``RED_A``.
-    If you want to use Manim constants like ``RED_A`` together with ``<span>``,
-    you will need to use Python's f-String syntax as follows:
-    ``f'<span foreground="{RED_A}">here you go</span>'``
+    For ``<span>`` markup, colors can be specified either as
+    hex triples like ``#aabbcc`` or as named CSS colors like
+    ``AliceBlue``.
+    The ``<gradient>`` tag is handled by Manim rather than
+    Pango, and supports hex triplets or Manim constants like
+    ``RED`` or ``RED_A``.
+    If you want to use Manim constants like ``RED_A`` together
+    with ``<span>``, you will need to use Python's f-String
+    syntax as follows::
 
-    If your text contains ligatures, the :class:`MarkupText` class may incorrectly determine
-    the first and last letter when creating the gradient. This is due to the fact that e.g. ``fl``
-    are two characters, but might be set as one single glyph, a ligature. If your language does
-    not depend on ligatures, consider setting ``disable_ligatures=True``. If you cannot or do
-    not want to do without ligatures, the ``gradient`` tag supports an optional attribute ``offset``
-    which can be used to compensate for that error. Usage is as follows:
+        MarkupText(f'<span foreground="{RED_A}">here you go</span>')
+
+    If your text contains ligatures, the :class:`MarkupText` class may
+    incorrectly determine the first and last letter when creating the
+    gradient. This is due to the fact that ``fl`` are two separate characters,
+    but might be set as one single glyph - a ligature. If your language
+    does not depend on ligatures, consider setting ``disable_ligatures``
+    to ``True``. If you must use ligatures, the ``gradient`` tag supports an optional
+    attribute ``offset`` which can be used to compensate for that error.
+
+    For example:
 
     - ``<gradient from="RED" to="YELLOW" offset="1">example</gradient>`` to *start* the gradient one letter earlier
     - ``<gradient from="RED" to="YELLOW" offset=",1">example</gradient>`` to *end* the gradient one letter earlier
@@ -714,20 +813,24 @@ class MarkupText(SVGMobject):
     itself contain ligatures. The same can happen when using HTML entities for
     special chars.
 
-    When using ``underline``, ``overline`` or ``strikethrough`` together with ``<gradient>`` tags, you will also need to use the offset, because
-    underlines are additional paths in the final :class:`SVGMobject`, check out the corresponding example.
+    When using ``underline``, ``overline`` or ``strikethrough`` together with
+    ``<gradient>`` tags, you will also need to use the offset, because
+    underlines are additional paths in the final :class:`SVGMobject`.
+    Check out the following example.
 
-    Escaping of special characters: ``>`` *should* be written as ``&gt;`` whereas ``<`` and
-    ``&`` *must* be written as ``&lt;`` and ``&amp;``.
+    Escaping of special characters: ``>`` **should** be written as ``&gt;``
+    whereas ``<`` and ``&`` *must* be written as ``&lt;`` and
+    ``&amp;``.
 
     You can find more information about Pango markup formatting at the
     corresponding documentation page:
-    `Pango Markup <https://developer.gnome.org/pango/1.46/pango-Markup.html>`_.
+    `Pango Markup <https://developer.gnome.org/pango/stable/pango-Markup.html>`_.
     Please be aware that not all features are supported by this class and that
     the ``<gradient>`` tag mentioned above is not supported by Pango.
 
     Parameters
     ----------
+
     text : :class:`str`
         The text that need to created as mobject.
     fill_opacity : :class:`int`
@@ -736,7 +839,7 @@ class MarkupText(SVGMobject):
         Stroke width.
     color : :class:`str`
         Global color setting for the entire text. Local overrides are possible.
-    size : :class:`int`
+    font_size : :class:`float`
         Font size.
     line_spacing : :class:`int`
         Line spacing.
@@ -868,16 +971,49 @@ class MarkupText(SVGMobject):
         class MultiLanguage(Scene):
             def construct(self):
                 morning = MarkupText("வணக்கம்", font="sans-serif")
-                chin = MarkupText(
-                    '見 角 言 谷  辛 <span fgcolor="blue">辰 辵 邑</span> 酉 釆 里!'
+                japanese = MarkupText(
+                    '<span fgcolor="blue">日本</span>へようこそ'
                 )  # works as in ``Text``.
-                mess = MarkupText("Multi-Language", style=BOLD)
+                mess = MarkupText("Multi-Language", weight=BOLD)
                 russ = MarkupText("Здравствуйте मस नम म ", font="sans-serif")
                 hin = MarkupText("नमस्ते", font="sans-serif")
-                japanese = MarkupText("臂猿「黛比」帶著孩子", font="sans-serif")
-                group = VGroup(morning, chin, mess, russ, hin, japanese).arrange(DOWN)
+                chinese = MarkupText("臂猿「黛比」帶著孩子", font="sans-serif")
+                group = VGroup(morning, japanese, mess, russ, hin, chinese).arrange(DOWN)
                 self.add(group)
 
+    You can justify the text by passing :attr:`justify` parameter.
+
+    .. manim:: JustifyText
+
+        class JustifyText(Scene):
+            def construct(self):
+                ipsum_text = (
+                    "Lorem ipsum dolor sit amet, consectetur adipiscing elit."
+                    "Praesent feugiat metus sit amet iaculis pulvinar. Nulla posuere "
+                    "quam a ex aliquam, eleifend consectetur tellus viverra. Aliquam "
+                    "fermentum interdum justo, nec rutrum elit pretium ac. Nam quis "
+                    "leo pulvinar, dignissim est at, venenatis nisi. Quisque mattis "
+                    "dolor ut euismod hendrerit. Nullam eu ante sollicitudin, commodo "
+                    "risus a, vehicula odio. Nam urna tortor, aliquam a nibh eu, commodo "
+                    "imperdiet arcu. Donec tincidunt commodo enim a tincidunt."
+                )
+                justified_text = MarkupText(ipsum_text, justify=True).scale(0.4)
+                not_justified_text = MarkupText(ipsum_text, justify=False).scale(0.4)
+                just_title = Title("Justified")
+                njust_title = Title("Not Justified")
+                self.add(njust_title, not_justified_text)
+                self.play(
+                    Transform(
+                        not_justified_text,
+                        justified_text,
+                    ),
+                    Transform(
+                        njust_title,
+                        just_title,
+                    ),
+                    run_time=2,
+                )
+                self.wait(1)
 
     Tests
     -----
@@ -889,17 +1025,24 @@ class MarkupText(SVGMobject):
 
     """
 
+    @deprecated_params(
+        params="size",
+        since="v0.10.0",
+        until="v0.11.0",
+        message="Use font_size instead. To convert old scale factors to font size, multiply by 48.",
+    )
     def __init__(
         self,
         text: str,
-        fill_opacity: int = 1,
-        stroke_width: int = 0,
-        color: str = WHITE,
-        size: int = 1,
+        fill_opacity: float = 1,
+        stroke_width: float = 0,
+        color: Color = WHITE,
+        font_size: float = DEFAULT_FONT_SIZE,
         line_spacing: int = -1,
         font: str = "",
         slant: str = NORMAL,
         weight: str = NORMAL,
+        justify: bool = False,
         gradient: tuple = None,
         tab_width: int = 4,
         height: int = None,
@@ -911,13 +1054,20 @@ class MarkupText(SVGMobject):
     ):
         self.text = text
         self.color = color
-        self.size = size
+        # deprecation
+        size = kwargs.pop("size", None)
+        if size is not None:
+            self._font_size = size * DEFAULT_FONT_SIZE
+        else:
+            self._font_size = float(font_size)
+
         self.line_spacing = line_spacing
         self.font = font
         self.slant = slant
         self.weight = weight
         self.gradient = gradient
         self.tab_width = tab_width
+        self.justify = justify
 
         self.original_text = text
         self.disable_ligatures = disable_ligatures
@@ -936,9 +1086,11 @@ class MarkupText(SVGMobject):
             raise ValueError(validate_error)
 
         if self.line_spacing == -1:
-            self.line_spacing = self.size + self.size * 0.3
+            self.line_spacing = (
+                self._font_size + self._font_size * DEFAULT_LINE_SPACING_SCALE
+            )
         else:
-            self.line_spacing = self.size + self.size * self.line_spacing
+            self.line_spacing = self._font_size + self._font_size * self.line_spacing
 
         file_name = self.text2svg()
         PangoUtils.remove_last_M(file_name)
@@ -998,13 +1150,35 @@ class MarkupText(SVGMobject):
         if height is None and width is None:
             self.scale(TEXT_MOB_SCALE_FACTOR)
 
+        self.initial_height = self.height
+
+    @property
+    def font_size(self):
+        return (
+            self.height
+            / self.initial_height
+            / TEXT_MOB_SCALE_FACTOR
+            * 2.4
+            * self._font_size
+            / DEFAULT_FONT_SIZE
+        )
+
+    @font_size.setter
+    def font_size(self, font_val):
+        # TODO: use pango's font size scaling.
+        if font_val <= 0:
+            raise ValueError("font_size must be greater than 0.")
+        else:
+            self.scale(font_val / self.font_size)
+
     def text2hash(self):
         """Generates ``sha256`` hash for file name."""
         settings = (
             "MARKUPPANGO" + self.font + self.slant + self.weight + self.color
         )  # to differentiate from classical Pango Text
-        settings += str(self.line_spacing) + str(self.size)
+        settings += str(self.line_spacing) + str(self._font_size)
         settings += str(self.disable_ligatures)
+        settings += str(self.justify)
         id_str = self.text + settings
         hasher = hashlib.sha256()
         hasher.update(id_str.encode())
@@ -1012,32 +1186,37 @@ class MarkupText(SVGMobject):
 
     def text2svg(self):
         """Convert the text to SVG using Pango."""
-        size = self.size * 10
-        line_spacing = self.line_spacing * 10
+        size = self._font_size
+        line_spacing = self.line_spacing
+        size /= TEXT2SVG_ADJUSTMENT_FACTOR
+        line_spacing /= TEXT2SVG_ADJUSTMENT_FACTOR
+
         dir_name = config.get_dir("text_dir")
-        disable_liga = self.disable_ligatures
         if not os.path.exists(dir_name):
             os.makedirs(dir_name)
         hash_name = self.text2hash()
         file_name = os.path.join(dir_name, hash_name) + ".svg"
         if os.path.exists(file_name):
-            return file_name
-
-        logger.debug(f"Setting Text {self.text}")
-        return MarkupUtils.text2svg(
-            f'<span foreground="{self.color}">{self.text}</span>',
-            self.font,
-            self.slant,
-            self.weight,
-            size,
-            line_spacing,
-            disable_liga,
-            file_name,
-            START_X,
-            START_Y,
-            600,  # width
-            400,  # height
-        )
+            svg_file = file_name
+        else:
+            logger.debug(f"Setting Text {self.text}")
+            svg_file = MarkupUtils.text2svg(
+                f'<span foreground="{self.color}">{self.text}</span>',
+                self.font,
+                self.slant,
+                self.weight,
+                size,
+                line_spacing,
+                self.disable_ligatures,
+                file_name,
+                START_X,
+                START_Y,
+                600,  # width
+                400,  # height
+                justify=self.justify,
+                pango_width=500,
+            )
+        return svg_file
 
     def _count_real_chars(self, s):
         """Counts characters that will be displayed.
@@ -1136,7 +1315,7 @@ class MarkupText(SVGMobject):
 
 
 @contextmanager
-def register_font(font_file: typing.Union[str, Path]):
+def register_font(font_file: Union[str, Path]):
     """Temporarily add a font file to Pango's search path.
 
     This searches for the font_file at various places. The order it searches it described below.
