@@ -26,8 +26,11 @@ class AbstractImageMobject(Mobject):
     Parameters
     ----------
     scale_to_resolution : :class:`int`
-        At this resolution the image is placed pixel by pixel onto the screen, so it will look the sharpest and best.
-        This is a custom parameter of ImageMobject so that rendering a scene with e.g. the ``--quality low`` or ``--quality medium`` flag for faster rendering won't effect the position of the image on the screen.
+        At this resolution the image is placed pixel by pixel onto the screen, so it
+        will look the sharpest and best.
+        This is a custom parameter of ImageMobject so that rendering a scene with
+        e.g. the ``--quality low`` or ``--quality medium`` flag for faster rendering
+        won't effect the position of the image on the screen.
     """
 
     def __init__(
@@ -40,7 +43,7 @@ class AbstractImageMobject(Mobject):
         self.pixel_array_dtype = pixel_array_dtype
         self.scale_to_resolution = scale_to_resolution
         self.set_resampling_algorithm(resampling_algorithm)
-        Mobject.__init__(self, **kwargs)
+        super().__init__(**kwargs)
 
     def get_pixel_array(self):
         raise NotImplementedError()
@@ -51,12 +54,16 @@ class AbstractImageMobject(Mobject):
 
     def set_resampling_algorithm(self, resampling_algorithm):
         """
-        Sets the interpolation method for upscaling the image. By default the image is interpolated using bicubic algorithm. This method lets you change it.
-        Interpolation is done internally using Pillow, and the function besides the string constants describing the algorithm accepts the Pillow integer constants.
+        Sets the interpolation method for upscaling the image. By default the image is
+        interpolated using bicubic algorithm. This method lets you change it.
+        Interpolation is done internally using Pillow, and the function besides the
+        string constants describing the algorithm accepts the Pillow integer constants.
 
         Parameters
         ----------
-        resampling_algorithm : :class:`int`, an integer constant described in the Pillow library, or one from the RESAMPLING_ALGORITHMS global dictionary, under the following keys:
+        resampling_algorithm : :class:`int`, an integer constant described in the
+        Pillow library, or one from the RESAMPLING_ALGORITHMS global dictionary, under
+        the following keys:
          * 'bicubic' or 'cubic'
          * 'nearest' or 'none'
          * 'box'
@@ -68,7 +75,10 @@ class AbstractImageMobject(Mobject):
             self.resampling_algorithm = resampling_algorithm
         else:
             raise ValueError(
-                "resampling_algorithm has to be an int, one of the values defined in RESAMPLING_ALGORITHMS or a Pillow resampling filter constant. Available algorithms: 'bicubic', 'nearest', 'box', 'bilinear', 'hamming', 'lanczos'."
+                "resampling_algorithm has to be an int, one of the values defined in "
+                "RESAMPLING_ALGORITHMS or a Pillow resampling filter constant. "
+                "Available algorithms: 'bicubic', 'nearest', 'box', 'bilinear', "
+                "'hamming', 'lanczos'."
             )
 
     def reset_points(self):
@@ -96,8 +106,11 @@ class ImageMobject(AbstractImageMobject):
     Parameters
     ----------
     scale_to_resolution : :class:`int`
-        At this resolution the image is placed pixel by pixel onto the screen, so it will look the sharpest and best.
-        This is a custom parameter of ImageMobject so that rendering a scene with e.g. the ``--quality low`` or ``--quality medium`` flag for faster rendering won't effect the position of the image on the screen.
+        At this resolution the image is placed pixel by pixel onto the screen, so it
+        will look the sharpest and best.
+        This is a custom parameter of ImageMobject so that rendering a scene with
+        e.g. the ``--quality low`` or ``--quality medium`` flag for faster rendering
+        won't effect the position of the image on the screen.
 
 
     Example
@@ -284,7 +297,7 @@ class ImageMobjectFromCamera(AbstractImageMobject):
             }
         self.default_display_frame_config = default_display_frame_config
         self.pixel_array = self.camera.pixel_array
-        AbstractImageMobject.__init__(self, scale_to_resolution=False, **kwargs)
+        super().__init__(scale_to_resolution=False, **kwargs)
 
     # TODO: Get rid of this.
     def get_pixel_array(self):
