@@ -1,16 +1,14 @@
 import itertools as it
 import operator as op
-import typing
 from functools import reduce, wraps
-from typing import Optional
+from typing import Callable, Iterable, Optional, Tuple
 
 import moderngl
 import numpy as np
 
+from ... import config
 from ...constants import *
 from ...mobject.opengl_mobject import OpenGLMobject, OpenGLPoint
-
-# from manimlib.utils.bezier import get_smooth_quadratic_bezier_handle_points
 from ...utils.bezier import (
     bezier,
     get_quadratic_approximation_of_cubic,
@@ -20,9 +18,8 @@ from ...utils.bezier import (
     partial_quadratic_bezier_points,
 )
 from ...utils.color import *
-
-# from manimlib.utils.iterables import resize_array
-# from manimlib.utils.color import rgb_to_hex
+from ...utils.config_ops import _Data
+from ...utils.deprecation import deprecated_params
 from ...utils.iterables import listify, make_even, resize_with_interpolation
 from ...utils.space_ops import (
     angle_between_vectors,
@@ -59,6 +56,11 @@ class OpenGLVMobject(OpenGLMobject):
     stroke_shader_folder = "quadratic_bezier_stroke"
     fill_shader_folder = "quadratic_bezier_fill"
 
+    fill_rgba = _Data()
+    stroke_rgba = _Data()
+    stroke_width = _Data()
+    unit_normal = _Data()
+
     def __init__(
         self,
         fill_color=None,
@@ -87,6 +89,7 @@ class OpenGLVMobject(OpenGLMobject):
         triangulation_locked=False,
         **kwargs,
     ):
+        self.data = {}
         self.fill_color = fill_color
         self.fill_opacity = fill_opacity
         self.stroke_color = stroke_color
@@ -117,6 +120,7 @@ class OpenGLVMobject(OpenGLMobject):
 
         self.needs_new_triangulation = True
         self.triangulation = np.zeros(0, dtype="i4")
+        self.orientation = 1
         super().__init__(**kwargs)
         self.refresh_unit_normal()
 
@@ -126,14 +130,10 @@ class OpenGLVMobject(OpenGLMobject):
     def init_data(self):
         super().init_data()
         self.data.pop("rgbas")
-        self.data.update(
-            {
-                "fill_rgba": np.zeros((1, 4)),
-                "stroke_rgba": np.zeros((1, 4)),
-                "stroke_width": np.zeros((1, 1)),
-                "unit_normal": np.zeros((1, 3)),
-            }
-        )
+        self.fill_rgba = np.zeros((1, 4))
+        self.stroke_rgba = np.zeros((1, 4))
+        self.unit_normal = np.zeros((1, 3))
+        # stroke_width belongs to self.data, but is defined through init_colors+set_stroke
 
     # Colors
     def init_colors(self):
@@ -162,9 +162,7 @@ class OpenGLVMobject(OpenGLMobject):
 
         if width is not None:
             for mob in self.get_family(recurse):
-                mob.data["stroke_width"] = np.array(
-                    [[width] for width in listify(width)]
-                )
+                mob.stroke_width = np.array([[width] for width in listify(width)])
 
         if background is not None:
             for mob in self.get_family(recurse):
@@ -185,16 +183,12 @@ class OpenGLVMobject(OpenGLMobject):
         recurse=True,
     ):
         if fill_rgba is not None:
-            self.data["fill_rgba"] = resize_with_interpolation(
-                fill_rgba, len(fill_rgba)
-            )
+            self.fill_rgba = resize_with_interpolation(fill_rgba, len(fill_rgba))
         else:
             self.set_fill(color=fill_color, opacity=fill_opacity, recurse=recurse)
 
         if stroke_rgba is not None:
-            self.data["stroke_rgba"] = resize_with_interpolation(
-                stroke_rgba, len(fill_rgba)
-            )
+            self.stroke_rgba = resize_with_interpolation(stroke_rgba, len(fill_rgba))
             self.set_stroke(width=stroke_width)
         else:
             self.set_stroke(
@@ -212,15 +206,18 @@ class OpenGLVMobject(OpenGLMobject):
 
     def get_style(self):
         return {
-            "fill_rgba": self.data["fill_rgba"],
-            "stroke_rgba": self.data["stroke_rgba"],
-            "stroke_width": self.data["stroke_width"],
-            "gloss": self.get_gloss(),
-            "shadow": self.get_shadow(),
+            "fill_rgba": self.fill_rgba,
+            "stroke_rgba": self.stroke_rgba,
+            "stroke_width": self.stroke_width,
+            "gloss": self.gloss,
+            "shadow": self.shadow,
         }
 
     def match_style(self, vmobject, recurse=True):
-        self.set_style(**vmobject.get_style(), recurse=False)
+        vmobject_style = vmobject.get_style()
+        if config.renderer == "opengl":
+            vmobject_style["stroke_width"] = vmobject_style["stroke_width"][0][0]
+        self.set_style(**vmobject_style, recurse=False)
         if recurse:
             # Does its best to match up submobject lists, and
             # match styles accordingly
@@ -257,19 +254,19 @@ class OpenGLVMobject(OpenGLMobject):
         return self
 
     def get_fill_colors(self):
-        return [rgb_to_hex(rgba[:3]) for rgba in self.data["fill_rgba"]]
+        return [rgb_to_hex(rgba[:3]) for rgba in self.fill_rgba]
 
     def get_fill_opacities(self):
-        return self.data["fill_rgba"][:, 3]
+        return self.fill_rgba[:, 3]
 
     def get_stroke_colors(self):
-        return [rgb_to_hex(rgba[:3]) for rgba in self.data["stroke_rgba"]]
+        return [rgb_to_hex(rgba[:3]) for rgba in self.stroke_rgba]
 
     def get_stroke_opacities(self):
-        return self.data["stroke_rgba"][:, 3]
+        return self.stroke_rgba[:, 3]
 
     def get_stroke_widths(self):
-        return self.data["stroke_width"]
+        return self.stroke_width
 
     # TODO, it's weird for these to return the first of various lists
     # rather than the full information
@@ -437,7 +434,7 @@ class OpenGLVMobject(OpenGLMobject):
         nppc = self.n_points_per_curve
         points = np.array(points)
         self.set_anchors_and_handles(
-            *[interpolate(points[:-1], points[1:], a) for a in np.linspace(0, 1, nppc)]
+            *(interpolate(points[:-1], points[1:], a) for a in np.linspace(0, 1, nppc))
         )
         return self
 
@@ -567,7 +564,7 @@ class OpenGLVMobject(OpenGLMobject):
 
     def get_nth_curve_function_with_length(
         self, n: int, sample_points: Optional[int] = None
-    ) -> typing.Tuple[typing.Callable[[float], np.ndarray], float]:
+    ) -> Tuple[Callable[[float], np.ndarray], float]:
         """Returns the expression of the nth curve along with its (approximate) length.
 
         Parameters
@@ -579,7 +576,7 @@ class OpenGLVMobject(OpenGLMobject):
 
         Returns
         -------
-        curve : typing.Callable[[float], np.ndarray]
+        curve : Callable[[float], np.ndarray]
             The function for the nth curve.
         length : :class:`float`
             The length of the nth curve.
@@ -603,12 +600,12 @@ class OpenGLVMobject(OpenGLMobject):
 
     def get_curve_functions(
         self,
-    ) -> typing.Iterable[typing.Callable[[float], np.ndarray]]:
+    ) -> Iterable[Callable[[float], np.ndarray]]:
         """Gets the functions for the curves of the mobject.
 
         Returns
         -------
-        typing.Iterable[typing.Callable[[float], np.ndarray]]
+        Iterable[Callable[[float], np.ndarray]]
             The functions for the curves.
         """
 
@@ -619,7 +616,7 @@ class OpenGLVMobject(OpenGLMobject):
 
     def get_curve_functions_with_lengths(
         self, **kwargs
-    ) -> typing.Iterable[typing.Tuple[typing.Callable[[float], np.ndarray], float]]:
+    ) -> Iterable[Tuple[Callable[[float], np.ndarray], float]]:
         """Gets the functions and lengths of the curves for the mobject.
 
         Parameters
@@ -629,7 +626,7 @@ class OpenGLVMobject(OpenGLMobject):
 
         Returns
         -------
-        typing.Iterable[typing.Tuple[typing.Callable[[float], np.ndarray], float]]
+        Iterable[Tuple[Callable[[float], np.ndarray], float]]
             The functions and lengths of the curves.
         """
 
@@ -781,9 +778,9 @@ class OpenGLVMobject(OpenGLMobject):
 
     def get_unit_normal(self, recompute=False):
         if not recompute:
-            return self.data["unit_normal"][0]
+            return self.unit_normal[0]
 
-        if len(self.data["points"]) < 3:
+        if len(self.points) < 3:
             return OUT
 
         area_vect = self.get_area_vector()
@@ -799,7 +796,7 @@ class OpenGLVMobject(OpenGLMobject):
 
     def refresh_unit_normal(self):
         for mob in self.get_family():
-            mob.data["unit_normal"][:] = mob.get_unit_normal(recompute=True)
+            mob.unit_normal[:] = mob.get_unit_normal(recompute=True)
         return self
 
     # Alignment
@@ -888,11 +885,14 @@ class OpenGLVMobject(OpenGLMobject):
 
     def interpolate(self, mobject1, mobject2, alpha, *args, **kwargs):
         super().interpolate(mobject1, mobject2, alpha, *args, **kwargs)
-        if self.has_fill():
-            tri1 = mobject1.get_triangulation()
-            tri2 = mobject2.get_triangulation()
-            if len(tri1) != len(tri1) or not np.all(tri1 == tri2):
-                self.refresh_triangulation()
+        if config["use_projection_fill_shaders"]:
+            self.refresh_triangulation()
+        else:
+            if self.has_fill():
+                tri1 = mobject1.get_triangulation()
+                tri2 = mobject2.get_triangulation()
+                if len(tri1) != len(tri1) or not np.all(tri1 == tri2):
+                    self.refresh_triangulation()
         return self
 
     def pointwise_become_partial(self, vmobject, a, b):
@@ -1018,9 +1018,14 @@ class OpenGLVMobject(OpenGLMobject):
     def triggers_refreshed_triangulation(func):
         @wraps(func)
         def wrapper(self, *args, **kwargs):
-            old_points = self.get_points().copy()
+            old_points = np.empty((0, 3))
+            for mob in self.family_members_with_points():
+                old_points = np.concatenate((old_points, mob.get_points()), axis=0)
             func(self, *args, **kwargs)
-            if not np.all(self.get_points() == old_points):
+            new_points = np.empty((0, 3))
+            for mob in self.family_members_with_points():
+                new_points = np.concatenate((new_points, mob.get_points()), axis=0)
+            if not np.all(new_points == old_points):
                 self.refresh_triangulation()
                 self.refresh_unit_normal()
 
@@ -1108,9 +1113,9 @@ class OpenGLVMobject(OpenGLMobject):
         stroke_shader_wrappers = []
         back_stroke_shader_wrappers = []
         for submob in self.family_members_with_points():
-            if submob.has_fill():
+            if submob.has_fill() and not config["use_projection_fill_shaders"]:
                 fill_shader_wrappers.append(submob.get_fill_shader_wrapper())
-            if submob.has_stroke():
+            if submob.has_stroke() and not config["use_projection_stroke_shaders"]:
                 ssw = submob.get_stroke_shader_wrapper()
                 if submob.draw_stroke_behind_fill:
                     back_stroke_shader_wrappers.append(ssw)
@@ -1145,7 +1150,7 @@ class OpenGLVMobject(OpenGLMobject):
         }
 
     def get_stroke_shader_data(self):
-        points = self.data["points"]
+        points = self.points
         stroke_data = np.zeros(len(points), dtype=OpenGLVMobject.stroke_dtype)
 
         nppc = self.n_points_per_curve
@@ -1162,7 +1167,7 @@ class OpenGLVMobject(OpenGLMobject):
         return stroke_data
 
     def get_fill_shader_data(self):
-        points = self.data["points"]
+        points = self.points
         fill_data = np.zeros(len(points), dtype=OpenGLVMobject.fill_dtype)
         fill_data["vert_index"][:, 0] = range(len(points))
 
@@ -1219,31 +1224,36 @@ class OpenGLCurvesAsSubmobjects(OpenGLVGroup):
 
 
 class OpenGLDashedVMobject(OpenGLVMobject):
+    @deprecated_params(
+        params="positive_space_ratio dash_spacing",
+        since="v0.9.0",
+        message="Use dashed_ratio instead of positive_space_ratio.",
+    )
     def __init__(
-        self, vmobject, num_dashes=15, positive_space_ratio=0.5, color=WHITE, **kwargs
+        self, vmobject, num_dashes=15, dashed_ratio=0.5, color=WHITE, **kwargs
     ):
+        # Simplify with removal of deprecation warning
+        self.dash_spacing = kwargs.pop("dash_spacing", None)  # Unused param
+        self.dashed_ratio = kwargs.pop("positive_space_ratio", None) or dashed_ratio
         self.num_dashes = num_dashes
-        self.positive_space_ratio = positive_space_ratio
         super().__init__(color=color, **kwargs)
-        num_dashes = self.num_dashes
-        ps_ratio = self.positive_space_ratio
+        r = self.dashed_ratio
+        n = self.num_dashes
         if num_dashes > 0:
-            # End points of the unit interval for division
-            alphas = np.linspace(0, 1, num_dashes + 1)
-
-            # This determines the length of each "dash"
-            full_d_alpha = 1.0 / num_dashes
-            partial_d_alpha = full_d_alpha * ps_ratio
-
-            # Rescale so that the last point of vmobject will
-            # be the end of the last dash
-            alphas /= 1 - full_d_alpha + partial_d_alpha
+            # Assuming total length is 1
+            dash_len = r / n
+            if vmobject.is_closed():
+                void_len = (1 - r) / n
+            else:
+                void_len = (1 - r) / (n - 1)
 
             self.add(
-                *[
-                    vmobject.get_subcurve(alpha, alpha + partial_d_alpha)
-                    for alpha in alphas[:-1]
-                ]
+                *(
+                    vmobject.get_subcurve(
+                        i * (dash_len + void_len), i * (dash_len + void_len) + dash_len
+                    )
+                    for i in range(n)
+                )
             )
         # Family is already taken care of by get_subcurve
         # implementation
