@@ -2,7 +2,7 @@ import itertools as it
 
 
 def extract_mobject_family_members(mobject_list, only_those_with_points=False):
-    result = list(it.chain(*[mob.get_family() for mob in mobject_list]))
+    result = list(it.chain(*(mob.get_family() for mob in mobject_list)))
     if only_those_with_points:
         result = [mob for mob in result if mob.has_points()]
     return result
