@@ -6,9 +6,14 @@ __all__ = [
     "seek_full_path_from_defaults",
     "modify_atime",
     "open_file",
+    "is_mp4_format",
+    "is_gif_format",
+    "is_png_format",
+    "is_webm_format",
+    "is_mov_format",
+    "write_to_movie",
 ]
 
-
 import os
 import platform
 import subprocess as sp
@@ -21,6 +26,93 @@ from manim import __version__, config, logger
 from .. import console
 
 
+def is_mp4_format() -> bool:
+    """
+    Determines if output format is .mp4
+
+    Returns
+    -------
+    class:`bool`
+        ``True`` if format is set as mp4
+
+    """
+    return config["format"] == "mp4"
+
+
+def is_gif_format() -> bool:
+    """
+    Determines if output format is .gif
+
+    Returns
+    -------
+    class:`bool`
+        ``True`` if format is set as gif
+
+    """
+    return config["format"] == "gif"
+
+
+def is_webm_format() -> bool:
+    """
+    Determines if output format is .webm
+
+    Returns
+    -------
+    class:`bool`
+        ``True`` if format is set as webm
+
+    """
+    return config["format"] == "webm"
+
+
+def is_mov_format() -> bool:
+    """
+    Determines if output format is .mov
+
+    Returns
+    -------
+    class:`bool`
+        ``True`` if format is set as mov
+
+    """
+    return config["format"] == "mov"
+
+
+def is_png_format() -> bool:
+    """
+    Determines if output format is .png
+
+    Returns
+    -------
+    class:`bool`
+        ``True`` if format is set as png
+
+    """
+    return config["format"] == "png"
+
+
+def write_to_movie() -> bool:
+    """
+    Determines from config if the output is a video format such as mp4 or gif, if the --format is set as 'png'
+    then it will take precedence event if the write_to_movie flag is set
+
+    Returns
+    -------
+    class:`bool`
+        ``True`` if the output should be written in a movie format
+
+    """
+    if is_png_format():
+        return False
+    return (
+        config["write_to_movie"]
+        or is_mp4_format()
+        or is_gif_format()
+        or is_webm_format()
+        or is_mov_format()
+    )
+
+
 def add_extension_if_not_present(file_name, extension):
     if file_name.suffix != extension:
         return file_name.with_suffix(extension)
@@ -49,7 +141,7 @@ def seek_full_path_from_defaults(file_name, default_dir, extensions):
         if os.path.exists(path):
             return path
     error = f"From: {os.getcwd()}, could not find {file_name} at either of these locations: {possible_paths}"
-    raise IOError(error)
+    raise OSError(error)
 
 
 def modify_atime(file_path):
@@ -87,9 +179,9 @@ def open_media_file(file_writer):
 
     if config["save_last_frame"]:
         file_paths.append(file_writer.image_file_path)
-    if config["write_to_movie"] and not config["format"] == "gif":
+    if write_to_movie() and not is_gif_format():
         file_paths.append(file_writer.movie_file_path)
-    if config["format"] == "gif":
+    if write_to_movie() and is_gif_format():
         file_paths.append(file_writer.gif_file_path)
 
     for file_path in file_paths:
@@ -98,7 +190,7 @@ def open_media_file(file_writer):
         if config["preview"]:
             open_file(file_path, False)
 
-            logger.info(f"Previewed File at: {file_path}")
+            logger.info(f"Previewed File at: '{file_path}'")
 
 
 def get_template_names():
