@@ -12,28 +12,36 @@ from typing import Any
 
 import numpy as np
 
-from .. import logger
+from .. import config, logger
 
-# Sometimes there are elements that are not suitable for hashing (too long or run-dependent)
-# This is used to filter them out.
-KEYS_TO_FILTER_OUT = set(
-    ["original_id", "background", "pixel_array", "pixel_array_to_cairo_context"]
-)
+# Sometimes there are elements that are not suitable for hashing (too long or
+# run-dependent).  This is used to filter them out.
+KEYS_TO_FILTER_OUT = {
+    "original_id",
+    "background",
+    "pixel_array",
+    "pixel_array_to_cairo_context",
+}
 
 
 class _Memoizer:
-    """Implements the memoization logic to optimize the hashing procedure and prevent the circular references within iterable processed.
+    """Implements the memoization logic to optimize the hashing procedure and prevent
+    the circular references within iterable processed.
 
-    Keeps a record of all the processed objects, and handle the logic to return a place holder instead of the original object if the object has already been processed
+    Keeps a record of all the processed objects, and handle the logic to return a place
+    holder instead of the original object if the object has already been processed
     by the hashing logic (i.e, recursively checked, converted to JSON, etc..).
 
-    This class uses two signatures functions to keep a track of processed objects : hash or id. Whenever possible, hash is used to ensure a broader object content-equality detection.
+    This class uses two signatures functions to keep a track of processed objects :
+    hash or id. Whenever possible, hash is used to ensure a broader object
+    content-equality detection.
     """
 
     _already_processed = set()
 
     # Can be changed to whatever string to help debugging the JSon generation.
-    ALREADY_PROCESSED_PLACEHOLDER = "ALREADY PROCESSED"
+    ALREADY_PROCESSED_PLACEHOLDER = "AP"
+    THRESHOLD_WARNING = 170_000
 
     @classmethod
     def reset_already_processed(cls):
@@ -41,7 +49,9 @@ class _Memoizer:
 
     @classmethod
     def check_already_processed_decorator(cls: "_Memoizer", is_method=False):
-        """Decorator to handle the arguments that goes through the decorated function. Returns _ALREADY_PROCESSED_PLACEHOLDER if the obj has been processed, or lets the decorated function call go ahead.
+        """Decorator to handle the arguments that goes through the decorated function.
+        Returns _ALREADY_PROCESSED_PLACEHOLDER if the obj has been processed, or lets
+        the decorated function call go ahead.
 
         Parameters
         ----------
@@ -50,7 +60,8 @@ class _Memoizer:
         """
 
         def layer(func):
-            # NOTE : There is probably a better way to separate both case when func is a method or a function.
+            # NOTE : There is probably a better way to separate both case when func is
+            # a method or a function.
             if is_method:
                 return lambda self, obj: cls._handle_already_processed(
                     obj, default_function=lambda obj: func(self, obj)
@@ -61,7 +72,8 @@ class _Memoizer:
 
     @classmethod
     def check_already_processed(cls, obj: Any) -> Any:
-        """Checks if obj has been already processed. Returns itself if it has not been, or the value of _ALREADY_PROCESSED_PLACEHOLDER if it has.
+        """Checks if obj has been already processed. Returns itself if it has not been,
+        or the value of _ALREADY_PROCESSED_PLACEHOLDER if it has.
         Marks the object as processed in the second case.
 
         Parameters
@@ -105,14 +117,15 @@ class _Memoizer:
             )
             and obj not in [None, cls.ALREADY_PROCESSED_PLACEHOLDER]
         ):
-            # It makes no sense (and it'd slower) to memoize objects of these primitive types.
-            # Hence, we simply return the object.
+            # It makes no sense (and it'd slower) to memoize objects of these primitive
+            # types.  Hence, we simply return the object.
             return obj
         if isinstance(obj, collections.abc.Hashable):
             try:
                 return cls._return(obj, hash, default_function)
             except TypeError:
-                # In case of an error with the hash (eg an object is marked as hashable but contains a non hashable within it)
+                # In case of an error with the hash (eg an object is marked as hashable
+                # but contains a non hashable within it)
                 # Fallback to use the built-in function id instead.
                 pass
         return cls._return(obj, id, default_function)
@@ -125,11 +138,25 @@ class _Memoizer:
         default_func,
         memoizing=True,
     ) -> typing.Union[str, Any]:
-
         obj_membership_sign = obj_to_membership_sign(obj)
         if obj_membership_sign in cls._already_processed:
             return cls.ALREADY_PROCESSED_PLACEHOLDER
         if memoizing:
+            if (
+                not config.disable_caching_warning
+                and len(cls._already_processed) == cls.THRESHOLD_WARNING
+            ):
+                logger.warning(
+                    "It looks like the scene contains a lot of sub-mobjects. Caching "
+                    "is sometimes not suited to handle such large scenes, you might "
+                    "consider disabling caching with --disable_caching to potentially "
+                    "speed up the rendering process."
+                )
+                logger.warning(
+                    "You can disable this warning by setting disable_caching_warning "
+                    "to True in your config file."
+                )
+
             cls._already_processed.add(obj_membership_sign)
         return default_func(obj)
 
@@ -139,10 +166,13 @@ class _CustomEncoder(json.JSONEncoder):
         """
         This method is used to serialize objects to JSON format.
 
-        If obj is a function, then it will return a dict with two keys : 'code', for the code source, and 'nonlocals' for all nonlocalsvalues. (including nonlocals functions, that will be serialized as this is recursive.)
+        If obj is a function, then it will return a dict with two keys : 'code', for
+        the code source, and 'nonlocals' for all nonlocalsvalues. (including nonlocals
+        functions, that will be serialized as this is recursive.)
         if obj is a np.darray, it converts it into a list.
         if obj is an object with __dict__ attribute, it returns its __dict__.
-        Else, will let the JSONEncoder do the stuff, and throw an error if the type is not suitable for JSONEncoder.
+        Else, will let the JSONEncoder do the stuff, and throw an error if the type is
+        not suitable for JSONEncoder.
 
         Parameters
         ----------
@@ -161,7 +191,8 @@ class _CustomEncoder(json.JSONEncoder):
             cvars = inspect.getclosurevars(obj)
             cvardict = {**copy.copy(cvars.globals), **copy.copy(cvars.nonlocals)}
             for i in list(cvardict):
-                # NOTE : All module types objects are removed, because otherwise it throws ValueError: Circular reference detected if not. TODO
+                # NOTE : All module types objects are removed, because otherwise it
+                # throws ValueError: Circular reference detected if not. TODO
                 if isinstance(cvardict[i], ModuleType):
                     del cvardict[i]
             try:
@@ -188,7 +219,8 @@ class _CustomEncoder(json.JSONEncoder):
             return self._cleaned_iterable(temp)
         elif isinstance(obj, np.uint8):
             return int(obj)
-        return f"Unsupported type for serializing -> {str(type(obj))}"
+        # Serialize it with only the type of the object. You can change this to whatever string when debugging the serialization process.
+        return str(type(obj))
 
     def _cleaned_iterable(self, iterable):
         """Check for circular reference at each iterable that will go through the JSONEncoder, as well as key of the wrong format.
@@ -308,10 +340,10 @@ def get_hash_from_play_call(
     camera_json = get_json(camera_object)
     animations_list_json = [get_json(x) for x in sorted(animations_list, key=str)]
     current_mobjects_list_json = [get_json(x) for x in current_mobjects_list]
-    hash_camera, hash_animations, hash_current_mobjects = [
+    hash_camera, hash_animations, hash_current_mobjects = (
         zlib.crc32(repr(json_val).encode())
         for json_val in [camera_json, animations_list_json, current_mobjects_list_json]
-    ]
+    )
     hash_complete = f"{hash_camera}_{hash_animations}_{hash_current_mobjects}"
     t_end = perf_counter()
     logger.debug("Hashing done in %(time)s s.", {"time": str(t_end - t_start)[:8]})
