@@ -1,13 +1,14 @@
 """Utilities for using Manim with IPython (in particular: Jupyter notebooks)"""
 
-import hashlib
 import mimetypes
 import os
 import shutil
+from datetime import datetime
 from pathlib import Path
 
-from manim import config, tempconfig
+from manim import Group, config, logger, tempconfig
 from manim.__main__ import main
+from manim.renderer.shader import shader_program_cache
 
 try:
     from IPython import get_ipython
@@ -25,7 +26,7 @@ else:
     @magics_class
     class ManimMagic(Magics):
         def __init__(self, shell):
-            super(ManimMagic, self).__init__(shell)
+            super().__init__(shell)
             self.rendered_files = {}
 
         @needs_local_scope
@@ -59,7 +60,7 @@ else:
                     def construct(self):
                         ...
 
-            Run ``%manim -h`` and ``%manim render -h`` for possible command line interface options.
+            Run ``%manim --help`` and ``%manim render --help`` for possible command line interface options.
 
             .. note::
 
@@ -102,16 +103,48 @@ else:
             if not len(args) or "-h" in args or "--help" in args or "--version" in args:
                 main(args, standalone_mode=False, prog_name="manim")
                 return
-            modified_args = ["--jupyter"] + args[:-1] + [""] + [args[-1]]
+            modified_args = self.add_additional_args(args)
             args = main(modified_args, standalone_mode=False, prog_name="manim")
             with tempconfig(local_ns.get("config", {})):
                 config.digest_args(args)
-                exec(f"{config['scene_names'][0]}().render()", local_ns)
+
+                renderer = None
+                if config.renderer == "opengl":
+                    # Check if the imported mobjects extend the OpenGLMobject class
+                    # meaning ConvertToOpenGL did its job
+                    if "OpenGLMobject" in map(lambda cls: cls.__name__, Group.mro()):
+                        from manim.renderer.opengl_renderer import OpenGLRenderer
+
+                        renderer = OpenGLRenderer()
+                    else:
+                        logger.warning(
+                            "Renderer must be set to OpenGL in the configuration file "
+                            "before importing Manim! Using cairo renderer instead."
+                        )
+                        config.renderer = "cairo"
+
+                try:
+                    SceneClass = local_ns[config["scene_names"][0]]
+                    scene = SceneClass(renderer=renderer)
+                    scene.render()
+                finally:
+                    # Shader cache becomes invalid as the context is destroyed
+                    shader_program_cache.clear()
+
+                    # Close OpenGL window here instead of waiting for the main thread to
+                    # finish causing the window to stay open and freeze
+                    if renderer is not None and renderer.window is not None:
+                        renderer.window.close()
+
+                if config["output_file"] is None:
+                    logger.info("No output file produced")
+                    return
+
                 local_path = Path(config["output_file"]).relative_to(Path.cwd())
                 tmpfile = (
                     Path(config["media_dir"])
                     / "jupyter"
-                    / f"{_video_hash(local_path)}{local_path.suffix}"
+                    / f"{_generate_file_name()}{local_path.suffix}"
                 )
 
                 if local_path in self.rendered_files:
@@ -136,13 +169,13 @@ else:
                     )
                 )
 
+        def add_additional_args(self, args):
+            additional_args = ["--jupyter"]
+            # Use webm to support transparency
+            if "-t" in args and "--format" not in args:
+                additional_args += ["--format", "webm"]
+            return additional_args + args[:-1] + [""] + [args[-1]]
 
-def _video_hash(path):
-    sha1 = hashlib.sha1()
-    with open(path, "rb") as f:
-        while True:
-            data = f.read(65536)
-            if not data:
-                break
-            sha1.update(data)
-    return sha1.hexdigest()
+
+def _generate_file_name():
+    return config["scene_names"][0] + "@" + datetime.now().strftime("%Y-%m-%d@%H-%M-%S")
