@@ -93,7 +93,7 @@ def binary_search(function, target, lower_bound, upper_bound, tolerance=1e-4):
     rh = upper_bound
     while abs(rh - lh) > tolerance:
         mh = np.mean([lh, rh])
-        lx, mx, rx = [function(h) for h in (lh, mh, rh)]
+        lx, mx, rx = (function(h) for h in (lh, mh, rh))
         if lx == target:
             return lx
         if rx == target:
